# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.pipeline import ClientRawResponse
from msrest.exceptions import HttpOperationError

from .. import models


class WeatherOperations(object):
    """WeatherOperations operations.

    :param client: Client for service requests.
    :param config: Configuration of service client.
    :param serializer: An object model serializer.
    :param deserializer: An object model deserializer.
    """

    models = models

    def __init__(self, client, config, serializer, deserializer):

        self._client = client
        self._serialize = serializer
        self._deserialize = deserializer

        self.config = config

    def parse_taf(
            self, options, custom_headers=None, raw=False, **operation_config):
        """Parses and validates a raw TAF report and returns parsed information in
        a format that can be more easily
        consumed.

        The TAF format doesn't contain contextual information about the date or
        month the TAF was issued. This
        information can be specified in the request as a ISO 8601 date format,
        typically as "YYYY-MM-DD" or
        "YYYY-MM".

        :param options: An object with the TAF string to parse along with
         extra information to help with
         parsing.
        :type options:
         ~emsapi.models.AdiEmsWebApiV2DtoWeatherTafTafParseOptions
        :param dict custom_headers: headers that will be added to the request
        :param bool raw: returns the direct response alongside the
         deserialized response
        :param operation_config: :ref:`Operation configuration
         overrides<msrest:optionsforoperations>`.
        :return: object or ClientRawResponse if raw=true
        :rtype: object or ~msrest.pipeline.ClientRawResponse
        :raises:
         :class:`HttpOperationError<msrest.exceptions.HttpOperationError>`
        """
        # Construct URL
        url = self.parse_taf.metadata['url']

        # Construct parameters
        query_parameters = {}

        # Construct headers
        header_parameters = {}
        header_parameters['Accept'] = 'application/json'
        header_parameters['Content-Type'] = 'application/json; charset=utf-8'
        if custom_headers:
            header_parameters.update(custom_headers)

        # Construct body
        body_content = self._serialize.body(options, 'AdiEmsWebApiV2DtoWeatherTafTafParseOptions')

        # Construct and send request
        request = self._client.post(url, query_parameters, header_parameters, body_content)
        response = self._client.send(request, stream=False, **operation_config)

        if response.status_code not in [200, 400, 401, 503]:
            raise HttpOperationError(self._deserialize, response)

        deserialized = None

        if response.status_code == 200:
            deserialized = self._deserialize('AdiEmsWebApiV2DtoWeatherTafTafReport', response)
        if response.status_code == 400:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)
        if response.status_code == 401:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)
        if response.status_code == 503:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)

        if raw:
            client_raw_response = ClientRawResponse(deserialized, response)
            return client_raw_response

        return deserialized
    parse_taf.metadata = {'url': '/v2/weather/taf/parse'}

    def parse_metar(
            self, options, custom_headers=None, raw=False, **operation_config):
        """Parses and validates a raw METAR report and returns parsed information
        in a format that can be more easily
        consumed.

        :param options: An object with the METAR string to parse.
        :type options:
         ~emsapi.models.AdiEmsWebApiV2DtoWeatherMetarMetarParseOptions
        :param dict custom_headers: headers that will be added to the request
        :param bool raw: returns the direct response alongside the
         deserialized response
        :param operation_config: :ref:`Operation configuration
         overrides<msrest:optionsforoperations>`.
        :return: object or ClientRawResponse if raw=true
        :rtype: object or ~msrest.pipeline.ClientRawResponse
        :raises:
         :class:`HttpOperationError<msrest.exceptions.HttpOperationError>`
        """
        # Construct URL
        url = self.parse_metar.metadata['url']

        # Construct parameters
        query_parameters = {}

        # Construct headers
        header_parameters = {}
        header_parameters['Accept'] = 'application/json'
        header_parameters['Content-Type'] = 'application/json; charset=utf-8'
        if custom_headers:
            header_parameters.update(custom_headers)

        # Construct body
        body_content = self._serialize.body(options, 'AdiEmsWebApiV2DtoWeatherMetarMetarParseOptions')

        # Construct and send request
        request = self._client.post(url, query_parameters, header_parameters, body_content)
        response = self._client.send(request, stream=False, **operation_config)

        if response.status_code not in [200, 400, 401, 503]:
            raise HttpOperationError(self._deserialize, response)

        deserialized = None

        if response.status_code == 200:
            deserialized = self._deserialize('AdiEmsWebApiV2DtoWeatherMetarMetarReport', response)
        if response.status_code == 400:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)
        if response.status_code == 401:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)
        if response.status_code == 503:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)

        if raw:
            client_raw_response = ClientRawResponse(deserialized, response)
            return client_raw_response

        return deserialized
    parse_metar.metadata = {'url': '/v2/weather/metar/parse'}

    def query_tafs(
            self, ems_system_id, options, custom_headers=None, raw=False, **operation_config):
        """Returns a list of collected TAF reports matching the specified search
        criteria for the provided EMS system.

        This API will return TAF reports matching your search options. If none
        are found, an empty list is returned.

        :param ems_system_id: The unique identifier of the system containing
         the EMS data.
        :type ems_system_id: int
        :param options: An object defining the search criteria to use for
         querying TAF reports.
        :type options: ~emsapi.models.AdiEmsWebApiV2DtoWeatherTafTafQuery
        :param dict custom_headers: headers that will be added to the request
        :param bool raw: returns the direct response alongside the
         deserialized response
        :param operation_config: :ref:`Operation configuration
         overrides<msrest:optionsforoperations>`.
        :return: object or ClientRawResponse if raw=true
        :rtype: object or ~msrest.pipeline.ClientRawResponse
        :raises:
         :class:`HttpOperationError<msrest.exceptions.HttpOperationError>`
        """
        # Construct URL
        url = self.query_tafs.metadata['url']
        path_format_arguments = {
            'emsSystemId': self._serialize.url("ems_system_id", ems_system_id, 'int')
        }
        url = self._client.format_url(url, **path_format_arguments)

        # Construct parameters
        query_parameters = {}

        # Construct headers
        header_parameters = {}
        header_parameters['Accept'] = 'application/json'
        header_parameters['Content-Type'] = 'application/json; charset=utf-8'
        if custom_headers:
            header_parameters.update(custom_headers)

        # Construct body
        body_content = self._serialize.body(options, 'AdiEmsWebApiV2DtoWeatherTafTafQuery')

        # Construct and send request
        request = self._client.post(url, query_parameters, header_parameters, body_content)
        response = self._client.send(request, stream=False, **operation_config)

        if response.status_code not in [200, 400, 401, 503]:
            raise HttpOperationError(self._deserialize, response)

        deserialized = None

        if response.status_code == 200:
            deserialized = self._deserialize('[AdiEmsWebApiV2DtoWeatherTafTafReport]', response)
        if response.status_code == 400:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)
        if response.status_code == 401:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)
        if response.status_code == 503:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)

        if raw:
            client_raw_response = ClientRawResponse(deserialized, response)
            return client_raw_response

        return deserialized
    query_tafs.metadata = {'url': '/v2/ems-systems/{emsSystemId}/weather/tafs'}

    def query_metars(
            self, ems_system_id, options, custom_headers=None, raw=False, **operation_config):
        """Returns a list of collected METAR reports matching the specified search
        criteria for the provided EMS
        system.

        This API will return METAR reports matching your search options. If
        none are found, an empty list is
        returned.

        :param ems_system_id: The unique identifier of the system containing
         the EMS data.
        :type ems_system_id: int
        :param options: An object defining the search criteria to use for
         querying METAR reports.
        :type options: ~emsapi.models.AdiEmsWebApiV2DtoWeatherMetarMetarQuery
        :param dict custom_headers: headers that will be added to the request
        :param bool raw: returns the direct response alongside the
         deserialized response
        :param operation_config: :ref:`Operation configuration
         overrides<msrest:optionsforoperations>`.
        :return: object or ClientRawResponse if raw=true
        :rtype: object or ~msrest.pipeline.ClientRawResponse
        :raises:
         :class:`HttpOperationError<msrest.exceptions.HttpOperationError>`
        """
        # Construct URL
        url = self.query_metars.metadata['url']
        path_format_arguments = {
            'emsSystemId': self._serialize.url("ems_system_id", ems_system_id, 'int')
        }
        url = self._client.format_url(url, **path_format_arguments)

        # Construct parameters
        query_parameters = {}

        # Construct headers
        header_parameters = {}
        header_parameters['Accept'] = 'application/json'
        header_parameters['Content-Type'] = 'application/json; charset=utf-8'
        if custom_headers:
            header_parameters.update(custom_headers)

        # Construct body
        body_content = self._serialize.body(options, 'AdiEmsWebApiV2DtoWeatherMetarMetarQuery')

        # Construct and send request
        request = self._client.post(url, query_parameters, header_parameters, body_content)
        response = self._client.send(request, stream=False, **operation_config)

        if response.status_code not in [200, 400, 401, 503]:
            raise HttpOperationError(self._deserialize, response)

        deserialized = None

        if response.status_code == 200:
            deserialized = self._deserialize('[AdiEmsWebApiV2DtoWeatherMetarMetarReport]', response)
        if response.status_code == 400:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)
        if response.status_code == 401:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)
        if response.status_code == 503:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)

        if raw:
            client_raw_response = ClientRawResponse(deserialized, response)
            return client_raw_response

        return deserialized
    query_metars.metadata = {'url': '/v2/ems-systems/{emsSystemId}/weather/metars'}

    def get_weather_for_flight(
            self, ems_system_id, flight_id, custom_headers=None, raw=False, **operation_config):
        """Returns a list of all collected TAF and METAR reports for a specified
        flight.

        <p>
        If the specified flight doesn't have any weather data, empty lists will
        be returned in the result.
        </p>
        <p>
        METAR and TAF reports that are related to flights in EMS can also be
        queried by building queries using the
        Database APIs. This API provides a simple wrapper around those APIs to
        make it easy to query for weather
        data
        </p>.

        :param ems_system_id: The unique identifier of the system containing
         the EMS data.
        :type ems_system_id: int
        :param flight_id: The integer ID of the flight record for which to
         return TAF reports.
        :type flight_id: int
        :param dict custom_headers: headers that will be added to the request
        :param bool raw: returns the direct response alongside the
         deserialized response
        :param operation_config: :ref:`Operation configuration
         overrides<msrest:optionsforoperations>`.
        :return: object or ClientRawResponse if raw=true
        :rtype: object or ~msrest.pipeline.ClientRawResponse
        :raises:
         :class:`HttpOperationError<msrest.exceptions.HttpOperationError>`
        """
        # Construct URL
        url = self.get_weather_for_flight.metadata['url']
        path_format_arguments = {
            'emsSystemId': self._serialize.url("ems_system_id", ems_system_id, 'int'),
            'flightId': self._serialize.url("flight_id", flight_id, 'int')
        }
        url = self._client.format_url(url, **path_format_arguments)

        # Construct parameters
        query_parameters = {}

        # Construct headers
        header_parameters = {}
        header_parameters['Accept'] = 'application/json'
        if custom_headers:
            header_parameters.update(custom_headers)

        # Construct and send request
        request = self._client.get(url, query_parameters, header_parameters)
        response = self._client.send(request, stream=False, **operation_config)

        if response.status_code not in [200, 401, 404, 503]:
            raise HttpOperationError(self._deserialize, response)

        deserialized = None

        if response.status_code == 200:
            deserialized = self._deserialize('AdiEmsWebApiV2DtoWeatherWeatherReport', response)
        if response.status_code == 401:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)
        if response.status_code == 404:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)
        if response.status_code == 503:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)

        if raw:
            client_raw_response = ClientRawResponse(deserialized, response)
            return client_raw_response

        return deserialized
    get_weather_for_flight.metadata = {'url': '/v2/ems-systems/{emsSystemId}/flights/{flightId}/weather'}

    def get_tafs_for_flight(
            self, ems_system_id, flight_id, custom_headers=None, raw=False, **operation_config):
        """Returns a list of collected TAF reports for a specified flight.

        <p>
        If the specified flight doesn't have any TAF reports, an empty list
        will be returned in the result.
        </p>
        <p>
        TAF reports that are related to flights in EMS can also be queried by
        building queries using the Database
        APIs. This API provides a simple wrapper around those APIs to make it
        easy to query for TAFs.
        </p>.

        :param ems_system_id: The unique identifier of the system containing
         the EMS data.
        :type ems_system_id: int
        :param flight_id: The integer ID of the flight record for which to
         return TAF reports.
        :type flight_id: int
        :param dict custom_headers: headers that will be added to the request
        :param bool raw: returns the direct response alongside the
         deserialized response
        :param operation_config: :ref:`Operation configuration
         overrides<msrest:optionsforoperations>`.
        :return: object or ClientRawResponse if raw=true
        :rtype: object or ~msrest.pipeline.ClientRawResponse
        :raises:
         :class:`HttpOperationError<msrest.exceptions.HttpOperationError>`
        """
        # Construct URL
        url = self.get_tafs_for_flight.metadata['url']
        path_format_arguments = {
            'emsSystemId': self._serialize.url("ems_system_id", ems_system_id, 'int'),
            'flightId': self._serialize.url("flight_id", flight_id, 'int')
        }
        url = self._client.format_url(url, **path_format_arguments)

        # Construct parameters
        query_parameters = {}

        # Construct headers
        header_parameters = {}
        header_parameters['Accept'] = 'application/json'
        if custom_headers:
            header_parameters.update(custom_headers)

        # Construct and send request
        request = self._client.get(url, query_parameters, header_parameters)
        response = self._client.send(request, stream=False, **operation_config)

        if response.status_code not in [200, 401, 404, 503]:
            raise HttpOperationError(self._deserialize, response)

        deserialized = None

        if response.status_code == 200:
            deserialized = self._deserialize('[AdiEmsWebApiV2DtoWeatherTafTafReport]', response)
        if response.status_code == 401:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)
        if response.status_code == 404:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)
        if response.status_code == 503:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)

        if raw:
            client_raw_response = ClientRawResponse(deserialized, response)
            return client_raw_response

        return deserialized
    get_tafs_for_flight.metadata = {'url': '/v2/ems-systems/{emsSystemId}/flights/{flightId}/weather/tafs'}

    def get_metars_for_flight(
            self, ems_system_id, flight_id, custom_headers=None, raw=False, **operation_config):
        """Returns a list of collected METAR reports for a specified flight.

        <p>
        If the specified flight doesn't have any METAR reports, an empty list
        will be returned in the result.
        </p>
        <p>
        METAR reports that are related to flights in EMS can also be queried by
        building queries using the Database
        APIs. This API provides a simple wrapper around those APIs to make it
        easy to query for METARs.
        </p>.

        :param ems_system_id: The unique identifier of the system containing
         the EMS data.
        :type ems_system_id: int
        :param flight_id: The integer ID of the flight record for which to
         return METAR reports.
        :type flight_id: int
        :param dict custom_headers: headers that will be added to the request
        :param bool raw: returns the direct response alongside the
         deserialized response
        :param operation_config: :ref:`Operation configuration
         overrides<msrest:optionsforoperations>`.
        :return: object or ClientRawResponse if raw=true
        :rtype: object or ~msrest.pipeline.ClientRawResponse
        :raises:
         :class:`HttpOperationError<msrest.exceptions.HttpOperationError>`
        """
        # Construct URL
        url = self.get_metars_for_flight.metadata['url']
        path_format_arguments = {
            'emsSystemId': self._serialize.url("ems_system_id", ems_system_id, 'int'),
            'flightId': self._serialize.url("flight_id", flight_id, 'int')
        }
        url = self._client.format_url(url, **path_format_arguments)

        # Construct parameters
        query_parameters = {}

        # Construct headers
        header_parameters = {}
        header_parameters['Accept'] = 'application/json'
        if custom_headers:
            header_parameters.update(custom_headers)

        # Construct and send request
        request = self._client.get(url, query_parameters, header_parameters)
        response = self._client.send(request, stream=False, **operation_config)

        if response.status_code not in [200, 401, 404, 503]:
            raise HttpOperationError(self._deserialize, response)

        deserialized = None

        if response.status_code == 200:
            deserialized = self._deserialize('[AdiEmsWebApiV2DtoWeatherMetarMetarReport]', response)
        if response.status_code == 401:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)
        if response.status_code == 404:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)
        if response.status_code == 503:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)

        if raw:
            client_raw_response = ClientRawResponse(deserialized, response)
            return client_raw_response

        return deserialized
    get_metars_for_flight.metadata = {'url': '/v2/ems-systems/{emsSystemId}/flights/{flightId}/weather/metars'}



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AdiEmsWebApiV2DtoEmsProfileProfileResults(Model):
    """Encapsulates all the profile results for a flight.

    All required parameters must be populated in order to send to Azure.

    :param profile_version: Required. The numeric version of the profile that
     was processed to generate the results. This
     corresponds to an index in the array of version history entries for the
     profile
    :type profile_version: int
    :param parameter_filtering: Required. Whether automatic parameter
     filtering was enabled when the profile was processed
    :type parameter_filtering: bool
    :param measurements: Required. The top-level (non-event-based)
     measurements
    :type measurements:
     list[~emsapi.models.AdiEmsWebApiV2DtoEmsProfileProfileResultValue]
    :param timepoints: Required. The top-level (non-event-based) timepoints
    :type timepoints:
     list[~emsapi.models.AdiEmsWebApiV2DtoEmsProfileProfileResultValue]
    :param events: Required. The events detected in the flight
    :type events:
     list[~emsapi.models.AdiEmsWebApiV2DtoEmsProfileProfileResultsEventRecord]
    """

    _validation = {
        'profile_version': {'required': True},
        'parameter_filtering': {'required': True},
        'measurements': {'required': True},
        'timepoints': {'required': True},
        'events': {'required': True},
    }

    _attribute_map = {
        'profile_version': {'key': 'profileVersion', 'type': 'int'},
        'parameter_filtering': {'key': 'parameterFiltering', 'type': 'bool'},
        'measurements': {'key': 'measurements', 'type': '[AdiEmsWebApiV2DtoEmsProfileProfileResultValue]'},
        'timepoints': {'key': 'timepoints', 'type': '[AdiEmsWebApiV2DtoEmsProfileProfileResultValue]'},
        'events': {'key': 'events', 'type': '[AdiEmsWebApiV2DtoEmsProfileProfileResultsEventRecord]'},
    }

    def __init__(self, **kwargs):
        super(AdiEmsWebApiV2DtoEmsProfileProfileResults, self).__init__(**kwargs)
        self.profile_version = kwargs.get('profile_version', None)
        self.parameter_filtering = kwargs.get('parameter_filtering', None)
        self.measurements = kwargs.get('measurements', None)
        self.timepoints = kwargs.get('timepoints', None)
        self.events = kwargs.get('events', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AdiEmsWebApiV2DtoWeatherTafTemperature(Model):
    """Describes a forecast temperature.

    :param valid_time: Describes the time at which the temperature forecast is
     valid
    :type valid_time: datetime
    :param surface: The expected surface temperature value
    :type surface: float
    :param maximum: The expected maximum temperature value
    :type maximum: float
    :param minimum: The expected minimum temperature value
    :type minimum: float
    """

    _attribute_map = {
        'valid_time': {'key': 'validTime', 'type': 'iso-8601'},
        'surface': {'key': 'surface', 'type': 'float'},
        'maximum': {'key': 'maximum', 'type': 'float'},
        'minimum': {'key': 'minimum', 'type': 'float'},
    }

    def __init__(self, *, valid_time=None, surface: float=None, maximum: float=None, minimum: float=None, **kwargs) -> None:
        super(AdiEmsWebApiV2DtoWeatherTafTemperature, self).__init__(**kwargs)
        self.valid_time = valid_time
        self.surface = surface
        self.maximum = maximum
        self.minimum = minimum



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AdiEmsWebApiV2DtoWeatherWeatherPhenomenon(Model):
    """Describes an individual weather phenomenon.

    All required parameters must be populated in order to send to Azure.

    :param unparsed: Required. The original, unparsed weather phenomenon
     string
    :type unparsed: str
    :param intensity: Describes the intensity of the whether phenomenon.
     Possible values include: 'light', 'moderate', 'heavy', 'vicinity'
    :type intensity: str or ~emsapi.models.enum
    :param qualifier: A qualifier for any weather precipitation. Possible
     values include: 'none', 'shallow', 'partial', 'patchy', 'drifting',
     'blowing', 'freezing', 'showers', 'thunderstorms'
    :type qualifier: str or ~emsapi.models.enum
    :param precipitation: The type of precipitation that this phenomenon
     represents. Possible values include: 'none', 'drizzle', 'rain', 'snow',
     'snowGrains', 'iceCrystals', 'icePellets', 'hail', 'smallHail', 'unknown'
    :type precipitation: str or ~emsapi.models.enum
    :param precipitation_secondary: The secondary type of precipitation that
     can be optionally specified to more accurately describe the
     precipitation. Possible values include: 'none', 'drizzle', 'rain', 'snow',
     'snowGrains', 'iceCrystals', 'icePellets', 'hail', 'smallHail', 'unknown'
    :type precipitation_secondary: str or ~emsapi.models.enum
    :param obscuration: Any weather that can obscure vision. Possible values
     include: 'none', 'mist', 'fog', 'smoke', 'volcanicAsh', 'dust', 'sand',
     'haze', 'spray'
    :type obscuration: str or ~emsapi.models.enum
    :param other: Other weather cases that do not fall under precipitation.
     Possible values include: 'none', 'dustWhirls', 'squalls', 'funnelCloud',
     'sandstorm', 'duststorm'
    :type other: str or ~emsapi.models.enum
    """

    _validation = {
        'unparsed': {'required': True},
    }

    _attribute_map = {
        'unparsed': {'key': 'unparsed', 'type': 'str'},
        'intensity': {'key': 'intensity', 'type': 'str'},
        'qualifier': {'key': 'qualifier', 'type': 'str'},
        'precipitation': {'key': 'precipitation', 'type': 'str'},
        'precipitation_secondary': {'key': 'precipitationSecondary', 'type': 'str'},
        'obscuration': {'key': 'obscuration', 'type': 'str'},
        'other': {'key': 'other', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(AdiEmsWebApiV2DtoWeatherWeatherPhenomenon, self).__init__(**kwargs)
        self.unparsed = kwargs.get('unparsed', None)
        self.intensity = kwargs.get('intensity', None)
        self.qualifier = kwargs.get('qualifier', None)
        self.precipitation = kwargs.get('precipitation', None)
        self.precipitation_secondary = kwargs.get('precipitation_secondary', None)
        self.obscuration = kwargs.get('obscuration', None)
        self.other = kwargs.get('other', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AdiEmsWebApiV2DtoSchemaFilter(Model):
    """Represents the operations and arguments that can be used to filter a data
    source query.

    All required parameters must be populated in order to send to Azure.

    :param operator: Required. The unique string identifier of the operation
     to perform. Possible values include: 'isTrue', 'isFalse', 'isNull',
     'isNotNull', 'and', 'or', 'not', 'in', 'notIn', 'plus', 'minus',
     'multiply', 'divide', 'modulo', 'equal', 'notEqual', 'lessThan',
     'lessThanOrEqual', 'greaterThan', 'greaterThanOrEqual',
     'betweenInclusive', 'betweenLowerExclusive', 'betweenUpperExclusive',
     'betweenExclusive', 'notBetweenInclusive', 'notBetweenLowerExclusive',
     'notBetweenUpperExclusive', 'notBetweenExclusive', 'integerRangeInclude',
     'integerRangeExclude', 'realRangeInclude', 'realRangeExclude', 'like',
     'notLike', 'allWords', 'anyWords', 'noWords', 'dateRelative',
     'dateSpecificMonths', 'dateSpecificMonth', 'dateBeforeMonth',
     'dateOnAfterMonth', 'dateSpecificDays', 'dateSpecificDay',
     'dateBeforeDay', 'dateOnAfterDay', 'dateTimeRange', 'dateTimeBefore',
     'dateTimeOnAfter', 'dateQuarterOfYear', 'dateMonthOfYear',
     'dateDayOfWeek', 'dateTimeHourOfDay'
    :type operator: str or ~emsapi.models.enum
    :param args: Required. An ordered list of arguments to provide the
     operator. The requirements for the arguments depend on which
     operation is being performed
    :type args: list[~emsapi.models.AdiEmsWebApiV2DtoSchemaFilterArgument]
    """

    _validation = {
        'operator': {'required': True},
        'args': {'required': True},
    }

    _attribute_map = {
        'operator': {'key': 'operator', 'type': 'str'},
        'args': {'key': 'args', 'type': '[AdiEmsWebApiV2DtoSchemaFilterArgument]'},
    }

    def __init__(self, *, operator, args, **kwargs) -> None:
        super(AdiEmsWebApiV2DtoSchemaFilter, self).__init__(**kwargs)
        self.operator = operator
        self.args = args



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AdiEmsWebApiV2DtoNavigationNavigationProcedure(Model):
    """Various pieces of information associated with a procedure.

    :param id: The unique identiifer for this procedure.
    :type id: int
    :param cycle_date: A text value representing the cycle date of the
     procedure.
    :type cycle_date: str
    :param emergency_safe_altitude: The emergency safe altitude of the
     procedure.
    :type emergency_safe_altitude: float
    :param string: A text identifier of the procedure.
    :type string: str
    :param transitional_altitude: The transition altitude of the procedure.
    :type transitional_altitude: float
    :param transitional_level: The transition level of the procedure.
    :type transitional_level: float
    :param type: The type of the procedure.
    :type type: str
    """

    _attribute_map = {
        'id': {'key': 'id', 'type': 'int'},
        'cycle_date': {'key': 'cycleDate', 'type': 'str'},
        'emergency_safe_altitude': {'key': 'emergencySafeAltitude', 'type': 'float'},
        'string': {'key': 'string', 'type': 'str'},
        'transitional_altitude': {'key': 'transitionalAltitude', 'type': 'float'},
        'transitional_level': {'key': 'transitionalLevel', 'type': 'float'},
        'type': {'key': 'type', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(AdiEmsWebApiV2DtoNavigationNavigationProcedure, self).__init__(**kwargs)
        self.id = kwargs.get('id', None)
        self.cycle_date = kwargs.get('cycle_date', None)
        self.emergency_safe_altitude = kwargs.get('emergency_safe_altitude', None)
        self.string = kwargs.get('string', None)
        self.transitional_altitude = kwargs.get('transitional_altitude', None)
        self.transitional_level = kwargs.get('transitional_level', None)
        self.type = kwargs.get('type', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AdiEmsWebApiV2DtoProfileGlossaryItem(Model):
    """Represents a single entry for an item in a profile glossary.

    All required parameters must be populated in order to send to Azure.

    :param record_type: Required. A value representing a profile glossary
     entries record type. Possible values include: 'measurement', 'timepoint',
     'event', 'interval'
    :type record_type: str or ~emsapi.models.enum
    :param scope: Required. A value representing the scope of the item.
     Possible values include: 'default', 'eventSpecific', 'eventGlobal'
    :type scope: str or ~emsapi.models.enum
    :param item_id: Required. A unique integer ID for the item
    :type item_id: int
    :param event_type_id: The event type ID of the item - this is only
     available for valid event types
    :type event_type_id: int
    :param data_type: A value representing the data type of the entry.
     Possible values include: 'floatingPoint'
    :type data_type: str or ~emsapi.models.enum
    :param logical_id: Required. A unique ID defining the item's logical ID
    :type logical_id: str
    :param name: Required. The display name of the item
    :type name: str
    :param units: An optional unit describing how the type of data represented
     by the item
    :type units: str
    :param first_associated_item_type: The item type of the first associated
     item. Possible values include: 'measurement', 'timepoint', 'event',
     'interval'
    :type first_associated_item_type: str or ~emsapi.models.enum
    :param first_associated_item_scope: The scope of the first associated
     item. Possible values include: 'default', 'eventSpecific', 'eventGlobal'
    :type first_associated_item_scope: str or ~emsapi.models.enum
    :param first_associated_item_id: The item id of the first associated item
    :type first_associated_item_id: int
    :param second_associated_item_type: The item type of the second associated
     item. Possible values include: 'measurement', 'timepoint', 'event',
     'interval'
    :type second_associated_item_type: str or ~emsapi.models.enum
    :param second_associated_item_scope: The scope of the second associated
     item. Possible values include: 'default', 'eventSpecific', 'eventGlobal'
    :type second_associated_item_scope: str or ~emsapi.models.enum
    :param second_associated_item_id: The item id of the second associated
     item
    :type second_associated_item_id: int
    """

    _validation = {
        'record_type': {'required': True},
        'scope': {'required': True},
        'item_id': {'required': True},
        'logical_id': {'required': True},
        'name': {'required': True},
    }

    _attribute_map = {
        'record_type': {'key': 'recordType', 'type': 'str'},
        'scope': {'key': 'scope', 'type': 'str'},
        'item_id': {'key': 'itemId', 'type': 'int'},
        'event_type_id': {'key': 'eventTypeId', 'type': 'int'},
        'data_type': {'key': 'dataType', 'type': 'str'},
        'logical_id': {'key': 'logicalId', 'type': 'str'},
        'name': {'key': 'name', 'type': 'str'},
        'units': {'key': 'units', 'type': 'str'},
        'first_associated_item_type': {'key': 'firstAssociatedItemType', 'type': 'str'},
        'first_associated_item_scope': {'key': 'firstAssociatedItemScope', 'type': 'str'},
        'first_associated_item_id': {'key': 'firstAssociatedItemId', 'type': 'int'},
        'second_associated_item_type': {'key': 'secondAssociatedItemType', 'type': 'str'},
        'second_associated_item_scope': {'key': 'secondAssociatedItemScope', 'type': 'str'},
        'second_associated_item_id': {'key': 'secondAssociatedItemId', 'type': 'int'},
    }

    def __init__(self, *, record_type, scope, item_id: int, logical_id: str, name: str, event_type_id: int=None, data_type=None, units: str=None, first_associated_item_type=None, first_associated_item_scope=None, first_associated_item_id: int=None, second_associated_item_type=None, second_associated_item_scope=None, second_associated_item_id: int=None, **kwargs) -> None:
        super(AdiEmsWebApiV2DtoProfileGlossaryItem, self).__init__(**kwargs)
        self.record_type = record_type
        self.scope = scope
        self.item_id = item_id
        self.event_type_id = event_type_id
        self.data_type = data_type
        self.logical_id = logical_id
        self.name = name
        self.units = units
        self.first_associated_item_type = first_associated_item_type
        self.first_associated_item_scope = first_associated_item_scope
        self.first_associated_item_id = first_associated_item_id
        self.second_associated_item_type = second_associated_item_type
        self.second_associated_item_scope = second_associated_item_scope
        self.second_associated_item_id = second_associated_item_id



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AdiEmsWebApiV2DtoWeatherMetarRunwayCondition(Model):
    """Describes the condition of a runway.

    All required parameters must be populated in order to send to Azure.

    :param unparsed: Required. The original, unparsed runway conditions string
    :type unparsed: str
    :param runway: Required. The name/number/approach direction identifying
     the runway
    :type runway: str
    :param deposit_type: The type of deposits currently on the runway.
     Possible values include: 'dry', 'damp', 'wet', 'frost', 'snowDry',
     'snowWet', 'slush', 'ice', 'snowCompacted', 'frozenRuts', 'none'
    :type deposit_type: str or ~emsapi.models.enum
    :param coverage: The coverage of deposits currently on the runway.
     Possible values include: 'coverage10Less', 'coverage11To25',
     'covarege26To50', 'coverage51To100', 'noInformation'
    :type coverage: str or ~emsapi.models.enum
    :param depth: Indicates the depth of deposits currently on the runway in
     centimeters
    :type depth: float
    :param braking: The "braking action" value describing the current braking
     conditions of the runway. Possible values include: 'unreliable', 'poor',
     'mediumPoor', 'medium', 'mediumGood', 'good', 'none'
    :type braking: str or ~emsapi.models.enum
    :param friction: The "coefficient of friction" value that alternatively
     describes the current braking conditions of the
     runway
    :type friction: float
    :param is_clear: Required. Indicating whether the runway conditions are
     clear of deposits
    :type is_clear: bool
    """

    _validation = {
        'unparsed': {'required': True},
        'runway': {'required': True},
        'is_clear': {'required': True},
    }

    _attribute_map = {
        'unparsed': {'key': 'unparsed', 'type': 'str'},
        'runway': {'key': 'runway', 'type': 'str'},
        'deposit_type': {'key': 'depositType', 'type': 'str'},
        'coverage': {'key': 'coverage', 'type': 'str'},
        'depth': {'key': 'depth', 'type': 'float'},
        'braking': {'key': 'braking', 'type': 'str'},
        'friction': {'key': 'friction', 'type': 'float'},
        'is_clear': {'key': 'isClear', 'type': 'bool'},
    }

    def __init__(self, *, unparsed: str, runway: str, is_clear: bool, deposit_type=None, coverage=None, depth: float=None, braking=None, friction: float=None, **kwargs) -> None:
        super(AdiEmsWebApiV2DtoWeatherMetarRunwayCondition, self).__init__(**kwargs)
        self.unparsed = unparsed
        self.runway = runway
        self.deposit_type = deposit_type
        self.coverage = coverage
        self.depth = depth
        self.braking = braking
        self.friction = friction
        self.is_clear = is_clear



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AdiEmsWebApiV2ModelTableauTrusted(Model):
    """Represents information that can be used to access Tableau content related
    to an associated Tableau server.

    :param trusted_url: The URL that can be used to start a trusted session
     with the Tableau server.
    :type trusted_url: str
    :param url: The root URL of the Tableau server with site.
    :type url: str
    :param site: The site that the TrustedUrl is able to access when used.
    :type site: str
    """

    _attribute_map = {
        'trusted_url': {'key': 'trustedUrl', 'type': 'str'},
        'url': {'key': 'url', 'type': 'str'},
        'site': {'key': 'site', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(AdiEmsWebApiV2ModelTableauTrusted, self).__init__(**kwargs)
        self.trusted_url = kwargs.get('trusted_url', None)
        self.url = kwargs.get('url', None)
        self.site = kwargs.get('site', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AdiEmsWebApiV2DtoSchemaAsyncQueryData(Model):
    """Represents the tabular results of a data source query obtained from an
    async query.

    All required parameters must be populated in order to send to Azure.

    :param rows: Required. An array of JSON string arrays, where each entry is
     a row in the results set
    :type rows: list[str]
    :param has_more_rows: Required. Whether the query has one or more rows in
     its result set at an index greater than the last row returned
    :type has_more_rows: bool
    """

    _validation = {
        'rows': {'required': True},
        'has_more_rows': {'required': True},
    }

    _attribute_map = {
        'rows': {'key': 'rows', 'type': '[str]'},
        'has_more_rows': {'key': 'hasMoreRows', 'type': 'bool'},
    }

    def __init__(self, **kwargs):
        super(AdiEmsWebApiV2DtoSchemaAsyncQueryData, self).__init__(**kwargs)
        self.rows = kwargs.get('rows', None)
        self.has_more_rows = kwargs.get('has_more_rows', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AdiEmsWebApiV2ModelAnalyticAnalyticSelect(Model):
    """Represents an individual analytic that can be selected in a query.

    All required parameters must be populated in order to send to Azure.

    :param analytic_id: Required. The unique string identifier of the analytic
     to select in a query
    :type analytic_id: str
    """

    _validation = {
        'analytic_id': {'required': True},
    }

    _attribute_map = {
        'analytic_id': {'key': 'analyticId', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(AdiEmsWebApiV2ModelAnalyticAnalyticSelect, self).__init__(**kwargs)
        self.analytic_id = kwargs.get('analytic_id', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AdiEmsWebApiV2DtoNavigationNavigationNavaid(Model):
    """Various pieces of information associated with a waypoint.

    :param id: The unique identifier of the navaid.
    :type id: int
    :param callsign: The radio callsign of the navaid.
    :type callsign: str
    :param type: The navaid type.
    :type type: str
    :param country_code: The navaid's country code.
    :type country_code: str
    :param state_code: The navaid's state code.
    :type state_code: int
    :param name: The official name of the navaid.
    :type name: str
    :param frequency: The radio frequency of the navaid.
    :type frequency: float
    :param usage_code: The airspace structure in which the navaid is utilized
     (e.g. high, low, terminal, etc.)
    :type usage_code: str
    :param channel: The navaid's radio channel.
    :type channel: str
    :param radio_class_code: The radio class code of the navaid (e.g.
     low-power NDB, high-power NDB, etc)
    :type radio_class_code: str
    :param range: The effective range of the navaid in nautical miles.
    :type range: float
    :param latitude: The latitude of the navaid.
    :type latitude: float
    :param longitude: The longitude of the navaid.
    :type longitude: float
    :param elevation: The navaid's elevation.
    :type elevation: float
    :param magnetic_variance: The magnetic varation from true north at the
     navaid.
    :type magnetic_variance: float
    :param dme_latitude: The latitude of the DME equipment colocated with the
     navaid, if any.
    :type dme_latitude: float
    :param dme_longitude: The longitude of the DME equipment colocated with
     the navaid, if any.
    :type dme_longitude: float
    :param dme_elevation: The elevation of the DME equipment colocated with
     the navaid, if any.
    :type dme_elevation: float
    :param associated_airport: The airport code of the associated airport, if
     any.
    :type associated_airport: str
    :param status: The status of the navaid (e.g. in service, out of service,
     etc.)
    :type status: str
    """

    _attribute_map = {
        'id': {'key': 'id', 'type': 'int'},
        'callsign': {'key': 'callsign', 'type': 'str'},
        'type': {'key': 'type', 'type': 'str'},
        'country_code': {'key': 'countryCode', 'type': 'str'},
        'state_code': {'key': 'stateCode', 'type': 'int'},
        'name': {'key': 'name', 'type': 'str'},
        'frequency': {'key': 'frequency', 'type': 'float'},
        'usage_code': {'key': 'usageCode', 'type': 'str'},
        'channel': {'key': 'channel', 'type': 'str'},
        'radio_class_code': {'key': 'radioClassCode', 'type': 'str'},
        'range': {'key': 'range', 'type': 'float'},
        'latitude': {'key': 'latitude', 'type': 'float'},
        'longitude': {'key': 'longitude', 'type': 'float'},
        'elevation': {'key': 'elevation', 'type': 'float'},
        'magnetic_variance': {'key': 'magneticVariance', 'type': 'float'},
        'dme_latitude': {'key': 'dmeLatitude', 'type': 'float'},
        'dme_longitude': {'key': 'dmeLongitude', 'type': 'float'},
        'dme_elevation': {'key': 'dmeElevation', 'type': 'float'},
        'associated_airport': {'key': 'associatedAirport', 'type': 'str'},
        'status': {'key': 'status', 'type': 'str'},
    }

    def __init__(self, *, id: int=None, callsign: str=None, type: str=None, country_code: str=None, state_code: int=None, name: str=None, frequency: float=None, usage_code: str=None, channel: str=None, radio_class_code: str=None, range: float=None, latitude: float=None, longitude: float=None, elevation: float=None, magnetic_variance: float=None, dme_latitude: float=None, dme_longitude: float=None, dme_elevation: float=None, associated_airport: str=None, status: str=None, **kwargs) -> None:
        super(AdiEmsWebApiV2DtoNavigationNavigationNavaid, self).__init__(**kwargs)
        self.id = id
        self.callsign = callsign
        self.type = type
        self.country_code = country_code
        self.state_code = state_code
        self.name = name
        self.frequency = frequency
        self.usage_code = usage_code
        self.channel = channel
        self.radio_class_code = radio_class_code
        self.range = range
        self.latitude = latitude
        self.longitude = longitude
        self.elevation = elevation
        self.magnetic_variance = magnetic_variance
        self.dme_latitude = dme_latitude
        self.dme_longitude = dme_longitude
        self.dme_elevation = dme_elevation
        self.associated_airport = associated_airport
        self.status = status



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AdiEmsWebApiV2DtoWeatherTafPrediction(Model):
    """Represents a forecast prediction originally included in a TAF.

    All required parameters must be populated in order to send to Azure.

    :param id: The ID used to uniquely identify this prediction on an EMS
     system
    :type id: int
    :param unparsed: Required. The original, unparsed prediction string
    :type unparsed: str
    :param time_from: The predicted start time for the weather in this
     prediction
    :type time_from: datetime
    :param time_to: The predicted end time for the weather in this prediction.
     This is defined by the following predictions start time
     or if it's the last prediction in a TAF it is the end of the validity
     window
    :type time_to: datetime
    :param time_becoming: The time that the prediction weather is expected to
     occur. This is only used with the "Becoming" change
     indicator
    :type time_becoming: datetime
    :param weather_change: Required. The type of conditions change indicator
     specified. When weather conditions are reported as changing this
     is "None". Possible values include: 'none', 'from', 'becoming',
     'temporary', 'probability', 'intermediate'
    :type weather_change: str or ~emsapi.models.enum
    :param probability: The probability of the weather described in this
     prediction occurring
    :type probability: int
    :param wind_direction: The wind direction in degrees or, if wind is
     variable this will be zero
    :type wind_direction: int
    :param wind_speed: The wind speed in knots
    :type wind_speed: int
    :param wind_gust_speed: The wind gust speed in knots, if wind gust data is
     present
    :type wind_gust_speed: int
    :param wind_shear_height: The wind shear height in feet, if wind shear
     data is present
    :type wind_shear_height: int
    :param wind_shear_direction: The wind shear direction in degrees, if wind
     shear data is present
    :type wind_shear_direction: int
    :param wind_shear_speed: The wind shear speed in knots, if wind shear data
     is present
    :type wind_shear_speed: int
    :param visibility_horizontal: The horizontal visibility in statute miles.
     Uses "Infinity" to indicate there is no limit
    :type visibility_horizontal: float
    :param visibility_vertical: The vertical visibility in feet above ground
     level
    :type visibility_vertical: int
    :param pressure: Pressure above ground level in inches of mercury
    :type pressure: float
    :param portion_not_decoded: Any parts of the raw prediction string that
     were unable to be decoded
    :type portion_not_decoded: str
    :param ceiling: The lowest altitude of "Broken" or "Overcast" cloud
     conditions or vertical visibility. Uses "Infinity" to
     indicate there is no limit
    :type ceiling: float
    :param cloud_conditions: A list of cloud conditions occurring during the
     prediction
    :type cloud_conditions:
     list[~emsapi.models.AdiEmsWebApiV2DtoWeatherCloudCondition]
    :param icing_conditions: A list of icing conditions occurring during the
     prediction
    :type icing_conditions:
     list[~emsapi.models.AdiEmsWebApiV2DtoWeatherTafIcingCondition]
    :param turbulence_conditions: A list of turbulence conditions occurring
     during the prediction
    :type turbulence_conditions:
     list[~emsapi.models.AdiEmsWebApiV2DtoWeatherTafTurbulenceCondition]
    :param temperatures: A list of temperature conditions occurring during the
     prediction
    :type temperatures:
     list[~emsapi.models.AdiEmsWebApiV2DtoWeatherTafTemperature]
    """

    _validation = {
        'unparsed': {'required': True},
        'weather_change': {'required': True},
    }

    _attribute_map = {
        'id': {'key': 'id', 'type': 'int'},
        'unparsed': {'key': 'unparsed', 'type': 'str'},
        'time_from': {'key': 'timeFrom', 'type': 'iso-8601'},
        'time_to': {'key': 'timeTo', 'type': 'iso-8601'},
        'time_becoming': {'key': 'timeBecoming', 'type': 'iso-8601'},
        'weather_change': {'key': 'weatherChange', 'type': 'str'},
        'probability': {'key': 'probability', 'type': 'int'},
        'wind_direction': {'key': 'windDirection', 'type': 'int'},
        'wind_speed': {'key': 'windSpeed', 'type': 'int'},
        'wind_gust_speed': {'key': 'windGustSpeed', 'type': 'int'},
        'wind_shear_height': {'key': 'windShearHeight', 'type': 'int'},
        'wind_shear_direction': {'key': 'windShearDirection', 'type': 'int'},
        'wind_shear_speed': {'key': 'windShearSpeed', 'type': 'int'},
        'visibility_horizontal': {'key': 'visibilityHorizontal', 'type': 'float'},
        'visibility_vertical': {'key': 'visibilityVertical', 'type': 'int'},
        'pressure': {'key': 'pressure', 'type': 'float'},
        'portion_not_decoded': {'key': 'portionNotDecoded', 'type': 'str'},
        'ceiling': {'key': 'ceiling', 'type': 'float'},
        'cloud_conditions': {'key': 'cloudConditions', 'type': '[AdiEmsWebApiV2DtoWeatherCloudCondition]'},
        'icing_conditions': {'key': 'icingConditions', 'type': '[AdiEmsWebApiV2DtoWeatherTafIcingCondition]'},
        'turbulence_conditions': {'key': 'turbulenceConditions', 'type': '[AdiEmsWebApiV2DtoWeatherTafTurbulenceCondition]'},
        'temperatures': {'key': 'temperatures', 'type': '[AdiEmsWebApiV2DtoWeatherTafTemperature]'},
    }

    def __init__(self, *, unparsed: str, weather_change, id: int=None, time_from=None, time_to=None, time_becoming=None, probability: int=None, wind_direction: int=None, wind_speed: int=None, wind_gust_speed: int=None, wind_shear_height: int=None, wind_shear_direction: int=None, wind_shear_speed: int=None, visibility_horizontal: float=None, visibility_vertical: int=None, pressure: float=None, portion_not_decoded: str=None, ceiling: float=None, cloud_conditions=None, icing_conditions=None, turbulence_conditions=None, temperatures=None, **kwargs) -> None:
        super(AdiEmsWebApiV2DtoWeatherTafPrediction, self).__init__(**kwargs)
        self.id = id
        self.unparsed = unparsed
        self.time_from = time_from
        self.time_to = time_to
        self.time_becoming = time_becoming
        self.weather_change = weather_change
        self.probability = probability
        self.wind_direction = wind_direction
        self.wind_speed = wind_speed
        self.wind_gust_speed = wind_gust_speed
        self.wind_shear_height = wind_shear_height
        self.wind_shear_direction = wind_shear_direction
        self.wind_shear_speed = wind_shear_speed
        self.visibility_horizontal = visibility_horizontal
        self.visibility_vertical = visibility_vertical
        self.pressure = pressure
        self.portion_not_decoded = portion_not_decoded
        self.ceiling = ceiling
        self.cloud_conditions = cloud_conditions
        self.icing_conditions = icing_conditions
        self.turbulence_conditions = turbulence_conditions
        self.temperatures = temperatures



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AdiEmsWebApiV2DtoWeatherTafTafQuery(Model):
    """Defines the options that can be used to query for TAF reports.

    :param airport_id: Optional airport ID for an airport returned by the
     Assets APIs. If set then ICAO code should not be set
    :type airport_id: int
    :param airport_icao: Optional airport ICAO code. If set then airportId
     should not be set
    :type airport_icao: str
    :param issue_range_from: Optional date range from filter. If set all TAFs
     issued after this value will be returned
    :type issue_range_from: datetime
    :param issue_range_to: Optional date range to filter. If set all TAFs
     issued before this value will be returned
    :type issue_range_to: datetime
    :param valid_range_from: Optional date range from filter. If set any TAF
     that is valid from this point to validRangeTo
     will be returned. If set validRangeTo must also be set
    :type valid_range_from: datetime
    :param valid_range_to: Optional date range from filter. If set any TAF
     that is valid to this point from validRangeFrom
     will be returned. If set validRangeFrom must also be set
    :type valid_range_to: datetime
    :param valid_time: Optional single time point for which to return all
     valid TAFs
    :type valid_time: datetime
    :param visibility_minimum: Optional value indicating the minimum observed
     visibility in miles. Since TAFs have multiple visibility values if any one
     value in the TAF meets
     this criteria that TAF will be returned
    :type visibility_minimum: float
    :param visibility_maximum: Optional value indicating the maximum observed
     visibility in miles. Since TAFs have multiple visibility values if any one
     value in the TAF meets
     this criteria that TAF will be returned
    :type visibility_maximum: float
    :param ceiling_minimum: Optional value indicating the minimum observed
     ceiling in feet. Since TAFs have multiple visibility values if any one
     value in the TAF meets
     this criteria that TAF will be returned
    :type ceiling_minimum: float
    :param ceiling_maximum: Optional value indicating the maximum observed
     ceiling in feet. Since TAFs have multiple visibility values if any one
     value in the TAF meets
     this criteria that TAF will be returned
    :type ceiling_maximum: float
    :param max_results: The maximum number of results to return. If set to 0
     all results will be returned. This defaults to 200
    :type max_results: int
    """

    _attribute_map = {
        'airport_id': {'key': 'airportId', 'type': 'int'},
        'airport_icao': {'key': 'airportIcao', 'type': 'str'},
        'issue_range_from': {'key': 'issueRangeFrom', 'type': 'iso-8601'},
        'issue_range_to': {'key': 'issueRangeTo', 'type': 'iso-8601'},
        'valid_range_from': {'key': 'validRangeFrom', 'type': 'iso-8601'},
        'valid_range_to': {'key': 'validRangeTo', 'type': 'iso-8601'},
        'valid_time': {'key': 'validTime', 'type': 'iso-8601'},
        'visibility_minimum': {'key': 'visibilityMinimum', 'type': 'float'},
        'visibility_maximum': {'key': 'visibilityMaximum', 'type': 'float'},
        'ceiling_minimum': {'key': 'ceilingMinimum', 'type': 'float'},
        'ceiling_maximum': {'key': 'ceilingMaximum', 'type': 'float'},
        'max_results': {'key': 'maxResults', 'type': 'int'},
    }

    def __init__(self, **kwargs):
        super(AdiEmsWebApiV2DtoWeatherTafTafQuery, self).__init__(**kwargs)
        self.airport_id = kwargs.get('airport_id', None)
        self.airport_icao = kwargs.get('airport_icao', None)
        self.issue_range_from = kwargs.get('issue_range_from', None)
        self.issue_range_to = kwargs.get('issue_range_to', None)
        self.valid_range_from = kwargs.get('valid_range_from', None)
        self.valid_range_to = kwargs.get('valid_range_to', None)
        self.valid_time = kwargs.get('valid_time', None)
        self.visibility_minimum = kwargs.get('visibility_minimum', None)
        self.visibility_maximum = kwargs.get('visibility_maximum', None)
        self.ceiling_minimum = kwargs.get('ceiling_minimum', None)
        self.ceiling_maximum = kwargs.get('ceiling_maximum', None)
        self.max_results = kwargs.get('max_results', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.pipeline import ClientRawResponse
from msrest.exceptions import HttpOperationError

from .. import models


class UploadOperations(object):
    """UploadOperations operations.

    :param client: Client for service requests.
    :param config: Configuration of service client.
    :param serializer: An object model serializer.
    :param deserializer: An object model deserializer.
    """

    models = models

    def __init__(self, client, config, serializer, deserializer):

        self._client = client
        self._serialize = serializer
        self._deserialize = deserializer

        self.config = config

    def get_buckets(
            self, custom_headers=None, raw=False, **operation_config):
        """Retrieves the buckets you have access to.

        :param dict custom_headers: headers that will be added to the request
        :param bool raw: returns the direct response alongside the
         deserialized response
        :param operation_config: :ref:`Operation configuration
         overrides<msrest:optionsforoperations>`.
        :return: object or ClientRawResponse if raw=true
        :rtype: object or ~msrest.pipeline.ClientRawResponse
        :raises:
         :class:`HttpOperationError<msrest.exceptions.HttpOperationError>`
        """
        # Construct URL
        url = self.get_buckets.metadata['url']

        # Construct parameters
        query_parameters = {}

        # Construct headers
        header_parameters = {}
        header_parameters['Accept'] = 'application/json'
        if custom_headers:
            header_parameters.update(custom_headers)

        # Construct and send request
        request = self._client.get(url, query_parameters, header_parameters)
        response = self._client.send(request, stream=False, **operation_config)

        if response.status_code not in [200, 401, 503]:
            raise HttpOperationError(self._deserialize, response)

        deserialized = None

        if response.status_code == 200:
            deserialized = self._deserialize('[AdiEmsWebApiV2DtoUploadBucket]', response)
        if response.status_code == 401:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)
        if response.status_code == 503:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)

        if raw:
            client_raw_response = ClientRawResponse(deserialized, response)
            return client_raw_response

        return deserialized
    get_buckets.metadata = {'url': '/v2/buckets'}

    def get_uploads(
            self, bucket_name, max_entries=None, custom_headers=None, raw=False, **operation_config):
        """Get a list of upload records from the server for a specific bucket.

        :param bucket_name: The name of the bucket to retrieve uploads for.
        :type bucket_name: str
        :param max_entries: The maximum number of entries to return; this is
         capped at 50, and
         50 will be used if it's not specified.
        :type max_entries: int
        :param dict custom_headers: headers that will be added to the request
        :param bool raw: returns the direct response alongside the
         deserialized response
        :param operation_config: :ref:`Operation configuration
         overrides<msrest:optionsforoperations>`.
        :return: object or ClientRawResponse if raw=true
        :rtype: object or ~msrest.pipeline.ClientRawResponse
        :raises:
         :class:`HttpOperationError<msrest.exceptions.HttpOperationError>`
        """
        # Construct URL
        url = self.get_uploads.metadata['url']
        path_format_arguments = {
            'bucketName': self._serialize.url("bucket_name", bucket_name, 'str')
        }
        url = self._client.format_url(url, **path_format_arguments)

        # Construct parameters
        query_parameters = {}
        if max_entries is not None:
            query_parameters['maxEntries'] = self._serialize.query("max_entries", max_entries, 'int')

        # Construct headers
        header_parameters = {}
        header_parameters['Accept'] = 'application/json'
        if custom_headers:
            header_parameters.update(custom_headers)

        # Construct and send request
        request = self._client.get(url, query_parameters, header_parameters)
        response = self._client.send(request, stream=False, **operation_config)

        if response.status_code not in [200, 401, 404, 503]:
            raise HttpOperationError(self._deserialize, response)

        deserialized = None

        if response.status_code == 200:
            deserialized = self._deserialize('[AdiEmsWebApiV2DtoUploadUploadRecord]', response)
        if response.status_code == 401:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)
        if response.status_code == 404:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)
        if response.status_code == 503:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)

        if raw:
            client_raw_response = ClientRawResponse(deserialized, response)
            return client_raw_response

        return deserialized
    get_uploads.metadata = {'url': '/v2/buckets/{bucketName}/uploads'}

    def start_async(
            self, bucket_name, request, custom_headers=None, raw=False, **operation_config):
        """Starts a new upload.

        :param bucket_name: The name of the bucket in which to start a new
         upload.
        :type bucket_name: str
        :param request: Information about the upload to start.
        :type request: ~emsapi.models.AdiEmsWebApiV2DtoUploadUploadRequest
        :param dict custom_headers: headers that will be added to the request
        :param bool raw: returns the direct response alongside the
         deserialized response
        :param operation_config: :ref:`Operation configuration
         overrides<msrest:optionsforoperations>`.
        :return: object or ClientRawResponse if raw=true
        :rtype: object or ~msrest.pipeline.ClientRawResponse
        :raises:
         :class:`HttpOperationError<msrest.exceptions.HttpOperationError>`
        """
        # Construct URL
        url = self.start_async.metadata['url']
        path_format_arguments = {
            'bucketName': self._serialize.url("bucket_name", bucket_name, 'str')
        }
        url = self._client.format_url(url, **path_format_arguments)

        # Construct parameters
        query_parameters = {}

        # Construct headers
        header_parameters = {}
        header_parameters['Accept'] = 'application/json'
        header_parameters['Content-Type'] = 'application/json; charset=utf-8'
        if custom_headers:
            header_parameters.update(custom_headers)

        # Construct body
        body_content = self._serialize.body(request, 'AdiEmsWebApiV2DtoUploadUploadRequest')

        # Construct and send request
        request = self._client.post(url, query_parameters, header_parameters, body_content)
        response = self._client.send(request, stream=False, **operation_config)

        if response.status_code not in [200, 401, 404, 503]:
            raise HttpOperationError(self._deserialize, response)

        deserialized = None

        if response.status_code == 200:
            deserialized = self._deserialize('AdiEmsWebApiV2DtoUploadUploadParameters', response)
        if response.status_code == 401:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)
        if response.status_code == 404:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)
        if response.status_code == 503:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)

        if raw:
            client_raw_response = ClientRawResponse(deserialized, response)
            return client_raw_response

        return deserialized
    start_async.metadata = {'url': '/v2/buckets/{bucketName}/uploads'}

    def chunk_async(
            self, bucket_name, transfer_id, first, last, custom_headers=None, raw=False, **operation_config):
        """Uploads a chunk of a file. This will fail if any chunks have been
        skipped in the specified file.

        The practical limit for a single chunk is less than 4MB or so,
        dependent on the web server's configuration.
        If you receive 500 responses, try smaller chunk sizes.

        :param bucket_name: The name of the bucket to which the client is
         uploading.
        :type bucket_name: str
        :param transfer_id: The ID of the upload, returned originally by the
         upload start call.
        :type transfer_id: str
        :param first: The byte index of the first byte that will be uploaded.
        :type first: long
        :param last: The byte index of the last byte that will be uploaded.
        :type last: long
        :param dict custom_headers: headers that will be added to the request
        :param bool raw: returns the direct response alongside the
         deserialized response
        :param operation_config: :ref:`Operation configuration
         overrides<msrest:optionsforoperations>`.
        :return: object or ClientRawResponse if raw=true
        :rtype: object or ~msrest.pipeline.ClientRawResponse
        :raises:
         :class:`HttpOperationError<msrest.exceptions.HttpOperationError>`
        """
        # Construct URL
        url = self.chunk_async.metadata['url']
        path_format_arguments = {
            'bucketName': self._serialize.url("bucket_name", bucket_name, 'str'),
            'transferId': self._serialize.url("transfer_id", transfer_id, 'str'),
            'first': self._serialize.url("first", first, 'long'),
            'last': self._serialize.url("last", last, 'long')
        }
        url = self._client.format_url(url, **path_format_arguments)

        # Construct parameters
        query_parameters = {}

        # Construct headers
        header_parameters = {}
        header_parameters['Accept'] = 'application/json'
        if custom_headers:
            header_parameters.update(custom_headers)

        # Construct and send request
        request = self._client.put(url, query_parameters, header_parameters)
        response = self._client.send(request, stream=False, **operation_config)

        if response.status_code not in [200, 400, 401, 404, 500, 503]:
            raise HttpOperationError(self._deserialize, response)

        deserialized = None

        if response.status_code == 200:
            deserialized = self._deserialize('AdiEmsWebApiV2DtoUploadUploadResult', response)
        if response.status_code == 400:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)
        if response.status_code == 401:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)
        if response.status_code == 404:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)
        if response.status_code == 500:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)
        if response.status_code == 503:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)

        if raw:
            client_raw_response = ClientRawResponse(deserialized, response)
            return client_raw_response

        return deserialized
    chunk_async.metadata = {'url': '/v2/buckets/{bucketName}/uploads/{transferId}/{first}/{last}'}

    def status(
            self, bucket_name, transfer_id, custom_headers=None, raw=False, **operation_config):
        """Gets the status of an upload in progress.

        :param bucket_name: The name of the bucket to which the client is
         uploading.
        :type bucket_name: str
        :param transfer_id: The ID of the upload, returned originally by the
         upload start call.
        :type transfer_id: str
        :param dict custom_headers: headers that will be added to the request
        :param bool raw: returns the direct response alongside the
         deserialized response
        :param operation_config: :ref:`Operation configuration
         overrides<msrest:optionsforoperations>`.
        :return: object or ClientRawResponse if raw=true
        :rtype: object or ~msrest.pipeline.ClientRawResponse
        :raises:
         :class:`HttpOperationError<msrest.exceptions.HttpOperationError>`
        """
        # Construct URL
        url = self.status.metadata['url']
        path_format_arguments = {
            'bucketName': self._serialize.url("bucket_name", bucket_name, 'str'),
            'transferId': self._serialize.url("transfer_id", transfer_id, 'str')
        }
        url = self._client.format_url(url, **path_format_arguments)

        # Construct parameters
        query_parameters = {}

        # Construct headers
        header_parameters = {}
        header_parameters['Accept'] = 'application/json'
        if custom_headers:
            header_parameters.update(custom_headers)

        # Construct and send request
        request = self._client.get(url, query_parameters, header_parameters)
        response = self._client.send(request, stream=False, **operation_config)

        if response.status_code not in [200, 401, 404, 503]:
            raise HttpOperationError(self._deserialize, response)

        deserialized = None

        if response.status_code == 200:
            deserialized = self._deserialize('AdiEmsWebApiV2DtoUploadUploadStatus', response)
        if response.status_code == 401:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)
        if response.status_code == 404:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)
        if response.status_code == 503:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)

        if raw:
            client_raw_response = ClientRawResponse(deserialized, response)
            return client_raw_response

        return deserialized
    status.metadata = {'url': '/v2/buckets/{bucketName}/uploads/{transferId}'}

    def finish_async(
            self, bucket_name, transfer_id, custom_headers=None, raw=False, **operation_config):
        """Completes an existing upload in progress.

        <p>This will examine everything that's been transferred to make sure
        that it is intact, then
        give a status report in response.</p>
        <p>The use of this call is not required unless the file is being
        streamed (i.e. there was no
        totalSize passed in the beginning of the file). In that case, this call
        is necessary to
        tell the server that all data are received.</p>.

        :param bucket_name: The name of the bucket to which the client is
         uploading.
        :type bucket_name: str
        :param transfer_id: The ID of the upload, returned originally by the
         upload start call.
        :type transfer_id: str
        :param dict custom_headers: headers that will be added to the request
        :param bool raw: returns the direct response alongside the
         deserialized response
        :param operation_config: :ref:`Operation configuration
         overrides<msrest:optionsforoperations>`.
        :return: object or ClientRawResponse if raw=true
        :rtype: object or ~msrest.pipeline.ClientRawResponse
        :raises:
         :class:`HttpOperationError<msrest.exceptions.HttpOperationError>`
        """
        # Construct URL
        url = self.finish_async.metadata['url']
        path_format_arguments = {
            'bucketName': self._serialize.url("bucket_name", bucket_name, 'str'),
            'transferId': self._serialize.url("transfer_id", transfer_id, 'str')
        }
        url = self._client.format_url(url, **path_format_arguments)

        # Construct parameters
        query_parameters = {}

        # Construct headers
        header_parameters = {}
        header_parameters['Accept'] = 'application/json'
        if custom_headers:
            header_parameters.update(custom_headers)

        # Construct and send request
        request = self._client.get(url, query_parameters, header_parameters)
        response = self._client.send(request, stream=False, **operation_config)

        if response.status_code not in [200, 400, 401, 404, 503]:
            raise HttpOperationError(self._deserialize, response)

        deserialized = None

        if response.status_code == 200:
            deserialized = self._deserialize('AdiEmsWebApiV2DtoUploadUploadResult', response)
        if response.status_code == 400:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)
        if response.status_code == 401:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)
        if response.status_code == 404:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)
        if response.status_code == 503:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)

        if raw:
            client_raw_response = ClientRawResponse(deserialized, response)
            return client_raw_response

        return deserialized
    finish_async.metadata = {'url': '/v2/buckets/{bucketName}/uploads/{transferId}/finish'}

    def cancel_async(
            self, bucket_name, transfer_id, custom_headers=None, raw=False, **operation_config):
        """Cancels an existing upload in progress.

        If successful, this call will delete the file in progress and set the
        associated database record to canceled.

        :param bucket_name: The name of the bucket to which the client is
         uploading.
        :type bucket_name: str
        :param transfer_id: The ID of the upload, returned originally by the
         upload start call.
        :type transfer_id: str
        :param dict custom_headers: headers that will be added to the request
        :param bool raw: returns the direct response alongside the
         deserialized response
        :param operation_config: :ref:`Operation configuration
         overrides<msrest:optionsforoperations>`.
        :return: object or ClientRawResponse if raw=true
        :rtype: object or ~msrest.pipeline.ClientRawResponse
        :raises:
         :class:`HttpOperationError<msrest.exceptions.HttpOperationError>`
        """
        # Construct URL
        url = self.cancel_async.metadata['url']
        path_format_arguments = {
            'bucketName': self._serialize.url("bucket_name", bucket_name, 'str'),
            'transferId': self._serialize.url("transfer_id", transfer_id, 'str')
        }
        url = self._client.format_url(url, **path_format_arguments)

        # Construct parameters
        query_parameters = {}

        # Construct headers
        header_parameters = {}
        header_parameters['Accept'] = 'application/json'
        if custom_headers:
            header_parameters.update(custom_headers)

        # Construct and send request
        request = self._client.get(url, query_parameters, header_parameters)
        response = self._client.send(request, stream=False, **operation_config)

        if response.status_code not in [200, 400, 401, 404, 503]:
            raise HttpOperationError(self._deserialize, response)

        deserialized = None

        if response.status_code == 200:
            deserialized = self._deserialize('AdiEmsWebApiV2DtoUploadUploadResult', response)
        if response.status_code == 400:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)
        if response.status_code == 401:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)
        if response.status_code == 404:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)
        if response.status_code == 503:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)

        if raw:
            client_raw_response = ClientRawResponse(deserialized, response)
            return client_raw_response

        return deserialized
    cancel_async.metadata = {'url': '/v2/buckets/{bucketName}/uploads/{transferId}/cancel'}

    def get_upload_processing_status(
            self, bucket_name, transfer_id, custom_headers=None, raw=False, **operation_config):
        """Gets the EMS processing status for a single upload.

        When using this route, make sure to use a bucket and upload ID that
        match. Results for IDs that do not
        exist will still return valid results, but will indicate that the
        uploading processing is incomplete,
        which, while true, may be misleading.

        :param bucket_name: The name of the bucket to query for the specified
         upload.
        :type bucket_name: str
        :param transfer_id: The ID of the upload for which to return status
         information.
        :type transfer_id: str
        :param dict custom_headers: headers that will be added to the request
        :param bool raw: returns the direct response alongside the
         deserialized response
        :param operation_config: :ref:`Operation configuration
         overrides<msrest:optionsforoperations>`.
        :return: object or ClientRawResponse if raw=true
        :rtype: object or ~msrest.pipeline.ClientRawResponse
        :raises:
         :class:`HttpOperationError<msrest.exceptions.HttpOperationError>`
        """
        # Construct URL
        url = self.get_upload_processing_status.metadata['url']
        path_format_arguments = {
            'bucketName': self._serialize.url("bucket_name", bucket_name, 'str'),
            'transferId': self._serialize.url("transfer_id", transfer_id, 'str')
        }
        url = self._client.format_url(url, **path_format_arguments)

        # Construct parameters
        query_parameters = {}

        # Construct headers
        header_parameters = {}
        header_parameters['Accept'] = 'application/json'
        if custom_headers:
            header_parameters.update(custom_headers)

        # Construct and send request
        request = self._client.get(url, query_parameters, header_parameters)
        response = self._client.send(request, stream=False, **operation_config)

        if response.status_code not in [200, 401, 404, 503]:
            raise HttpOperationError(self._deserialize, response)

        deserialized = None

        if response.status_code == 200:
            deserialized = self._deserialize('AdiEmsWebApiV2DtoUploadUploadProcessingStatus', response)
        if response.status_code == 401:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)
        if response.status_code == 404:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)
        if response.status_code == 503:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)

        if raw:
            client_raw_response = ClientRawResponse(deserialized, response)
            return client_raw_response

        return deserialized
    get_upload_processing_status.metadata = {'url': '/v2/buckets/{bucketName}/uploads/processing-status/{transferId}'}

    def get_upload_processing_status_multiple(
            self, bucket_name, ids, custom_headers=None, raw=False, **operation_config):
        """Gets the EMS processing status for a set of uploads.

        When using this route, make sure to use a bucket and upload IDs that
        match. Results for IDs that do not
        exist will still return valid results, but will indicate that the
        uploading processing is incomplete,
        which, while true, may be misleading.

        :param bucket_name: The name of the bucket to query for the specified
         uploads.
        :type bucket_name: str
        :param ids: The list of IDs of the upload for which to return status
         information.
        :type ids: list[str]
        :param dict custom_headers: headers that will be added to the request
        :param bool raw: returns the direct response alongside the
         deserialized response
        :param operation_config: :ref:`Operation configuration
         overrides<msrest:optionsforoperations>`.
        :return: object or ClientRawResponse if raw=true
        :rtype: object or ~msrest.pipeline.ClientRawResponse
        :raises:
         :class:`HttpOperationError<msrest.exceptions.HttpOperationError>`
        """
        # Construct URL
        url = self.get_upload_processing_status_multiple.metadata['url']
        path_format_arguments = {
            'bucketName': self._serialize.url("bucket_name", bucket_name, 'str')
        }
        url = self._client.format_url(url, **path_format_arguments)

        # Construct parameters
        query_parameters = {}

        # Construct headers
        header_parameters = {}
        header_parameters['Accept'] = 'application/json'
        header_parameters['Content-Type'] = 'application/json; charset=utf-8'
        if custom_headers:
            header_parameters.update(custom_headers)

        # Construct body
        body_content = self._serialize.body(ids, '[str]')

        # Construct and send request
        request = self._client.post(url, query_parameters, header_parameters, body_content)
        response = self._client.send(request, stream=False, **operation_config)

        if response.status_code not in [200, 400, 401, 404, 503]:
            raise HttpOperationError(self._deserialize, response)

        deserialized = None

        if response.status_code == 200:
            deserialized = self._deserialize('{AdiEmsWebApiV2DtoUploadUploadProcessingStatus}', response)
        if response.status_code == 400:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)
        if response.status_code == 401:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)
        if response.status_code == 404:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)
        if response.status_code == 503:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)

        if raw:
            client_raw_response = ClientRawResponse(deserialized, response)
            return client_raw_response

        return deserialized
    get_upload_processing_status_multiple.metadata = {'url': '/v2/buckets/{bucketName}/uploads/processing-status'}



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AdiEmsWebApiV2DtoParameterSetParameterSetItem(Model):
    """A container for parameter sets.

    :param chart_index: The index of the chart that this analytic info belongs
     to, or null if no index specified.
    :type chart_index: int
    :param parameter: The analytic that is represented by this parameter set
     item.
    :type parameter: ~emsapi.models.AdiEmsWebApiV2DtoAnalyticInfo
    :param custom_name: The custom name the user specified for the item, or
     null if not-specified.
    :type custom_name: str
    :param color: The color to use for the line in hexadecimal color
     specification "#RRGGBB", or null if no color specified.
    :type color: str
    :param custom_range: Optional override for the vertical scale for a
     parameter.
    :type custom_range: ~emsapi.models.AdiEmsWebApiCoreDtoDataRange
    :param custom_digits_after_decimal: Optional override for the number of
     digits to display.
    :type custom_digits_after_decimal: int
    :param line_width: Optional value from 1 to 5 for the width of the line.
    :type line_width: int
    :param display_sample_marker: Optional value specifying whether the
     parrmeter should display shapes to indicate the sampled values.
    :type display_sample_marker: bool
    :param sample_marker_shape: If set, describes the shape to use for the
     sampled values.
     Possible values: [Square, Circle, Triangle, InvertedTriangle, Cross, Star]
    :type sample_marker_shape: str
    :param line_style: If set, describes the line style to use when drawing.
     Possible values: [Dash, Dot, DashDot, DashDotDot, Solid]
    :type line_style: str
    """

    _attribute_map = {
        'chart_index': {'key': 'chartIndex', 'type': 'int'},
        'parameter': {'key': 'parameter', 'type': 'AdiEmsWebApiV2DtoAnalyticInfo'},
        'custom_name': {'key': 'customName', 'type': 'str'},
        'color': {'key': 'color', 'type': 'str'},
        'custom_range': {'key': 'customRange', 'type': 'AdiEmsWebApiCoreDtoDataRange'},
        'custom_digits_after_decimal': {'key': 'customDigitsAfterDecimal', 'type': 'int'},
        'line_width': {'key': 'lineWidth', 'type': 'int'},
        'display_sample_marker': {'key': 'displaySampleMarker', 'type': 'bool'},
        'sample_marker_shape': {'key': 'sampleMarkerShape', 'type': 'str'},
        'line_style': {'key': 'lineStyle', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(AdiEmsWebApiV2DtoParameterSetParameterSetItem, self).__init__(**kwargs)
        self.chart_index = kwargs.get('chart_index', None)
        self.parameter = kwargs.get('parameter', None)
        self.custom_name = kwargs.get('custom_name', None)
        self.color = kwargs.get('color', None)
        self.custom_range = kwargs.get('custom_range', None)
        self.custom_digits_after_decimal = kwargs.get('custom_digits_after_decimal', None)
        self.line_width = kwargs.get('line_width', None)
        self.display_sample_marker = kwargs.get('display_sample_marker', None)
        self.sample_marker_shape = kwargs.get('sample_marker_shape', None)
        self.line_style = kwargs.get('line_style', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AdiEmsWebApiV2DtoAssetAircraft(Model):
    """An aircraft in the system refers to an airframe with a particular tail
    number.

    :param id: The identifier of the aircraft within the system
    :type id: int
    :param description: The description for this aircraft
    :type description: str
    :param fleet_ids: Each aircraft can be mapped to 0-N fleets in the system.
     Because a fleet represents a configuration for a airframe and those
     configurations can change over time,
     it stands to reason that each aircraft can be mapped to more than one of
     them
    :type fleet_ids: list[int]
    :param is_active: Whether this aircraft is active in the system
    :type is_active: bool
    :param is_approved: Whether this aircraft has been approved
    :type is_approved: bool
    """

    _attribute_map = {
        'id': {'key': 'id', 'type': 'int'},
        'description': {'key': 'description', 'type': 'str'},
        'fleet_ids': {'key': 'fleetIds', 'type': '[int]'},
        'is_active': {'key': 'isActive', 'type': 'bool'},
        'is_approved': {'key': 'isApproved', 'type': 'bool'},
    }

    def __init__(self, **kwargs):
        super(AdiEmsWebApiV2DtoAssetAircraft, self).__init__(**kwargs)
        self.id = kwargs.get('id', None)
        self.description = kwargs.get('description', None)
        self.fleet_ids = kwargs.get('fleet_ids', None)
        self.is_active = kwargs.get('is_active', None)
        self.is_approved = kwargs.get('is_approved', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AdiEmsWebApiV2DtoEmsProfileProfileResultValue(Model):
    """Encapsulates information about a profile results value (measurement or
    timepoint).

    All required parameters must be populated in order to send to Azure.

    :param item_id: Required. The id of the item in the profile.
    :type item_id: int
    :param data_value: The computed data value for the given item
    :type data_value: float
    """

    _validation = {
        'item_id': {'required': True},
    }

    _attribute_map = {
        'item_id': {'key': 'itemId', 'type': 'int'},
        'data_value': {'key': 'dataValue', 'type': 'float'},
    }

    def __init__(self, **kwargs):
        super(AdiEmsWebApiV2DtoEmsProfileProfileResultValue, self).__init__(**kwargs)
        self.item_id = kwargs.get('item_id', None)
        self.data_value = kwargs.get('data_value', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AdiEmsWebApiV2DtoUploadUploadParameters(Model):
    """Passed back to the client when a multi-part upload is started. This
    contains further
    instructions on how to proceed with the upload, including the transfer ID
    to pass to
    future calls, as well as any change of URL for the actual chunk uploads.

    :param transfer_id: The ID of the transfer; this will be used when making
     subsequent calls to the upload APIs
    :type transfer_id: str
    :param url: The URL for the transfer; data block transfers regarding this
     upload should go to this URL.
     This may also be an empty string, in which case you should keep using the
     normal URLs
    :type url: str
    """

    _attribute_map = {
        'transfer_id': {'key': 'transferId', 'type': 'str'},
        'url': {'key': 'url', 'type': 'str'},
    }

    def __init__(self, *, transfer_id: str=None, url: str=None, **kwargs) -> None:
        super(AdiEmsWebApiV2DtoUploadUploadParameters, self).__init__(**kwargs)
        self.transfer_id = transfer_id
        self.url = url



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AdiEmsWebApiV2DtoTrajectoryValueArray(Model):
    """Encapsulates the data returned when requesting trajectory values through
    the API.

    :param values: The points in the generated trajectory.
    :type values: list[~emsapi.models.AdiEmsWebApiV2DtoTrajectoryValue]
    """

    _attribute_map = {
        'values': {'key': 'values', 'type': '[AdiEmsWebApiV2DtoTrajectoryValue]'},
    }

    def __init__(self, *, values=None, **kwargs) -> None:
        super(AdiEmsWebApiV2DtoTrajectoryValueArray, self).__init__(**kwargs)
        self.values = values



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AdiEmsWebApiV2ModelAnalyticQueryResult(Model):
    """Represents the time-series data result of an analytic query.

    All required parameters must be populated in order to send to Azure.

    :param offsets: Required. An array of query result offsets, each
     representing seconds from the start of the data
    :type offsets: list[float]
    :param results: Required. An array of analytic result values for each of
     the analytics selected in the query containing values for
     each offset
    :type results:
     list[~emsapi.models.AdiEmsWebApiV2ModelAnalyticAnalyticResult]
    """

    _validation = {
        'offsets': {'required': True},
        'results': {'required': True},
    }

    _attribute_map = {
        'offsets': {'key': 'offsets', 'type': '[float]'},
        'results': {'key': 'results', 'type': '[AdiEmsWebApiV2ModelAnalyticAnalyticResult]'},
    }

    def __init__(self, *, offsets, results, **kwargs) -> None:
        super(AdiEmsWebApiV2ModelAnalyticQueryResult, self).__init__(**kwargs)
        self.offsets = offsets
        self.results = results



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AdiEmsWebApiV2DtoMetadata(Model):
    """Encapsulates metadata information for a parameter or analytic in EMS.

    :param values: The metadata for the object.
    :type values: list[~emsapi.models.AdiEmsWebApiV2DtoMetadataItem]
    """

    _attribute_map = {
        'values': {'key': 'values', 'type': '[AdiEmsWebApiV2DtoMetadataItem]'},
    }

    def __init__(self, *, values=None, **kwargs) -> None:
        super(AdiEmsWebApiV2DtoMetadata, self).__init__(**kwargs)
        self.values = values



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AdiEmsWebApiV2DtoProfileProfileGlossary(Model):
    """A glossary for a specific profile. This describes the type of items found
    in a profile.

    All required parameters must be populated in order to send to Azure.

    :param glossary_version: Required. The integer version of the glossary
    :type glossary_version: int
    :param profile_local_id: Required. The local integer identifier of the
     associated profile
    :type profile_local_id: int
    :param profile_id: Required. The globally unique identifier of the
     associated profile
    :type profile_id: str
    :param current_version: Required. The integer version of the associated
     profile
    :type current_version: int
    :param current_version_guid: Required. The globally unique identifier for
     the version of the associated profile
    :type current_version_guid: str
    :param glossary_items: Required. A list of all entries contained in the
     glossary
    :type glossary_items:
     list[~emsapi.models.AdiEmsWebApiV2DtoProfileGlossaryItem]
    """

    _validation = {
        'glossary_version': {'required': True},
        'profile_local_id': {'required': True},
        'profile_id': {'required': True},
        'current_version': {'required': True},
        'current_version_guid': {'required': True},
        'glossary_items': {'required': True},
    }

    _attribute_map = {
        'glossary_version': {'key': 'glossaryVersion', 'type': 'int'},
        'profile_local_id': {'key': 'profileLocalId', 'type': 'int'},
        'profile_id': {'key': 'profileId', 'type': 'str'},
        'current_version': {'key': 'currentVersion', 'type': 'int'},
        'current_version_guid': {'key': 'currentVersionGuid', 'type': 'str'},
        'glossary_items': {'key': 'glossaryItems', 'type': '[AdiEmsWebApiV2DtoProfileGlossaryItem]'},
    }

    def __init__(self, *, glossary_version: int, profile_local_id: int, profile_id: str, current_version: int, current_version_guid: str, glossary_items, **kwargs) -> None:
        super(AdiEmsWebApiV2DtoProfileProfileGlossary, self).__init__(**kwargs)
        self.glossary_version = glossary_version
        self.profile_local_id = profile_local_id
        self.profile_id = profile_id
        self.current_version = current_version
        self.current_version_guid = current_version_guid
        self.glossary_items = glossary_items



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AdiEmsWebApiV2DtoNavigationNavigationProcedureSegment(Model):
    """Various pieces of information associated with a procedure segment.

    :param type: The segment type.
    :type type: str
    :param transition_id: The procedure segment id.
    :type transition_id: str
    :param sequence_number: The procedure segment sequence number.
    :type sequence_number: int
    :param track_code: The procedure segment
    :type track_code: str
    :param waypoint_id: The procedure segment waypoint id.
    :type waypoint_id: int
    :param waypoint_desc_codes: The procedure segment waypoint description
     codes.
    :type waypoint_desc_codes: list[str]
    :param waypoint_bearing: The bearing to the waypoint.
    :type waypoint_bearing: float
    :param waypoint_distance: The distance to the waypoint.
    :type waypoint_distance: float
    :param navaids: The navaids referenced by this segment.
    :type navaids:
     list[~emsapi.models.AdiEmsWebApiV2DtoNavigationNavigationProcedureSegmentNavaid]
    :param turn_direction: The procedure segment turn direction.
    :type turn_direction: str
    :param altitude_description: The procedure segment altitude description.
    :type altitude_description: str
    :param altitude1: The procedure segment altitude 1.
    :type altitude1: str
    :param altitude2: The procedure segment altitude 2.
    :type altitude2: str
    """

    _attribute_map = {
        'type': {'key': 'type', 'type': 'str'},
        'transition_id': {'key': 'transitionId', 'type': 'str'},
        'sequence_number': {'key': 'sequenceNumber', 'type': 'int'},
        'track_code': {'key': 'trackCode', 'type': 'str'},
        'waypoint_id': {'key': 'waypointId', 'type': 'int'},
        'waypoint_desc_codes': {'key': 'waypointDescCodes', 'type': '[str]'},
        'waypoint_bearing': {'key': 'waypointBearing', 'type': 'float'},
        'waypoint_distance': {'key': 'waypointDistance', 'type': 'float'},
        'navaids': {'key': 'navaids', 'type': '[AdiEmsWebApiV2DtoNavigationNavigationProcedureSegmentNavaid]'},
        'turn_direction': {'key': 'turnDirection', 'type': 'str'},
        'altitude_description': {'key': 'altitudeDescription', 'type': 'str'},
        'altitude1': {'key': 'altitude1', 'type': 'str'},
        'altitude2': {'key': 'altitude2', 'type': 'str'},
    }

    def __init__(self, *, type: str=None, transition_id: str=None, sequence_number: int=None, track_code: str=None, waypoint_id: int=None, waypoint_desc_codes=None, waypoint_bearing: float=None, waypoint_distance: float=None, navaids=None, turn_direction: str=None, altitude_description: str=None, altitude1: str=None, altitude2: str=None, **kwargs) -> None:
        super(AdiEmsWebApiV2DtoNavigationNavigationProcedureSegment, self).__init__(**kwargs)
        self.type = type
        self.transition_id = transition_id
        self.sequence_number = sequence_number
        self.track_code = track_code
        self.waypoint_id = waypoint_id
        self.waypoint_desc_codes = waypoint_desc_codes
        self.waypoint_bearing = waypoint_bearing
        self.waypoint_distance = waypoint_distance
        self.navaids = navaids
        self.turn_direction = turn_direction
        self.altitude_description = altitude_description
        self.altitude1 = altitude1
        self.altitude2 = altitude2



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.pipeline import ClientRawResponse
from msrest.exceptions import HttpOperationError

from .. import models


class ProfileOperations(object):
    """ProfileOperations operations.

    :param client: Client for service requests.
    :param config: Configuration of service client.
    :param serializer: An object model serializer.
    :param deserializer: An object model deserializer.
    """

    models = models

    def __init__(self, client, config, serializer, deserializer):

        self._client = client
        self._serialize = serializer
        self._deserialize = deserializer

        self.config = config

    def get_profile_results(
            self, ems_system_id, flight_id, profile_id, custom_headers=None, raw=False, **operation_config):
        """Queries profile results for a specified flight and profile.

        <p>This API allows retrieving all of the timepoints, measurements, and
        events calculated for a
        specific flight with the configured profile.</p>
        <p>Use this API in conjunction with
        "ems-systems/{emsSystemId}/flights/{flightId}/profiles/{profileId}/glossary"
        API so you can interpret and
        better understand the results returned in the results.</p>.

        :param ems_system_id: The unique identifier of the system containing
         the EMS data.
        :type ems_system_id: int
        :param flight_id: The integer ID of the flight record to use when
         retrieving profile information.
        :type flight_id: int
        :param profile_id: The unique identifier of the APM profile, e.g.
         "A7483C44-9DB9-4A44-9EB5-F67681EE52B0" for
         the library flight safety events profile.
        :type profile_id: str
        :param dict custom_headers: headers that will be added to the request
        :param bool raw: returns the direct response alongside the
         deserialized response
        :param operation_config: :ref:`Operation configuration
         overrides<msrest:optionsforoperations>`.
        :return: object or ClientRawResponse if raw=true
        :rtype: object or ~msrest.pipeline.ClientRawResponse
        :raises:
         :class:`HttpOperationError<msrest.exceptions.HttpOperationError>`
        """
        # Construct URL
        url = self.get_profile_results.metadata['url']
        path_format_arguments = {
            'emsSystemId': self._serialize.url("ems_system_id", ems_system_id, 'int'),
            'flightId': self._serialize.url("flight_id", flight_id, 'int'),
            'profileId': self._serialize.url("profile_id", profile_id, 'str')
        }
        url = self._client.format_url(url, **path_format_arguments)

        # Construct parameters
        query_parameters = {}

        # Construct headers
        header_parameters = {}
        header_parameters['Accept'] = 'application/json'
        if custom_headers:
            header_parameters.update(custom_headers)

        # Construct and send request
        request = self._client.get(url, query_parameters, header_parameters)
        response = self._client.send(request, stream=False, **operation_config)

        if response.status_code not in [200, 401, 404, 503]:
            raise HttpOperationError(self._deserialize, response)

        deserialized = None

        if response.status_code == 200:
            deserialized = self._deserialize('AdiEmsWebApiV2DtoProfileProfileResults', response)
        if response.status_code == 401:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)
        if response.status_code == 404:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)
        if response.status_code == 503:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)

        if raw:
            client_raw_response = ClientRawResponse(deserialized, response)
            return client_raw_response

        return deserialized
    get_profile_results.metadata = {'url': '/v2/ems-systems/{emsSystemId}/flights/{flightId}/profiles/{profileId}/query'}

    def get_profile_group(
            self, ems_system_id, group_id=None, custom_headers=None, raw=False, **operation_config):
        """Returns a profile group with a matching ID containing only its
        immediate children in a hierarchical tree
        used to organize profiles.

        Each EMS system has its own configured set of profiles that are
        available. Profiles are organized using
        profile groups in a tree structure since EMS systems might expose a
        large number of profiles. This API
        allows you to see one level of the tree structure.

        :param ems_system_id: The unique identifier of the system containing
         the EMS data.
        :type ems_system_id: int
        :param group_id: The unique identifier of the profile group whose
         contents to return. If not
         specified, the contents of the root group are returned.
        :type group_id: str
        :param dict custom_headers: headers that will be added to the request
        :param bool raw: returns the direct response alongside the
         deserialized response
        :param operation_config: :ref:`Operation configuration
         overrides<msrest:optionsforoperations>`.
        :return: object or ClientRawResponse if raw=true
        :rtype: object or ~msrest.pipeline.ClientRawResponse
        :raises:
         :class:`HttpOperationError<msrest.exceptions.HttpOperationError>`
        """
        # Construct URL
        url = self.get_profile_group.metadata['url']
        path_format_arguments = {
            'emsSystemId': self._serialize.url("ems_system_id", ems_system_id, 'int')
        }
        url = self._client.format_url(url, **path_format_arguments)

        # Construct parameters
        query_parameters = {}
        if group_id is not None:
            query_parameters['groupId'] = self._serialize.query("group_id", group_id, 'str')

        # Construct headers
        header_parameters = {}
        header_parameters['Accept'] = 'application/json'
        if custom_headers:
            header_parameters.update(custom_headers)

        # Construct and send request
        request = self._client.get(url, query_parameters, header_parameters)
        response = self._client.send(request, stream=False, **operation_config)

        if response.status_code not in [200, 401, 404, 503]:
            raise HttpOperationError(self._deserialize, response)

        deserialized = None

        if response.status_code == 200:
            deserialized = self._deserialize('AdiEmsWebApiV2DtoProfileProfileGroup', response)
        if response.status_code == 401:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)
        if response.status_code == 404:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)
        if response.status_code == 503:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)

        if raw:
            client_raw_response = ClientRawResponse(deserialized, response)
            return client_raw_response

        return deserialized
    get_profile_group.metadata = {'url': '/v2/ems-systems/{emsSystemId}/profile-groups'}

    def get_profiles(
            self, ems_system_id, group_id=None, search=None, custom_headers=None, raw=False, **operation_config):
        """Returns all the profiles matching the specified search options.

        <p>
        This API will return profiles matching your search options. If no
        profiles are found, an empty list is
        returned.
        </p>
        <p>
        It is common for a large number of profiles to be defined on an EMS
        system. To reduce the size and complexity
        of your query, try to specify a parent profile group ID and/or a name
        to use in the search.
        </p>.

        :param ems_system_id: The unique identifier of the system containing
         the EMS data.
        :type ems_system_id: int
        :param group_id: The optional parent profile group ID whose contents
         to search.
        :type group_id: str
        :param search: An optional profile name search string used to match
         profiles to return.
        :type search: str
        :param dict custom_headers: headers that will be added to the request
        :param bool raw: returns the direct response alongside the
         deserialized response
        :param operation_config: :ref:`Operation configuration
         overrides<msrest:optionsforoperations>`.
        :return: object or ClientRawResponse if raw=true
        :rtype: object or ~msrest.pipeline.ClientRawResponse
        :raises:
         :class:`HttpOperationError<msrest.exceptions.HttpOperationError>`
        """
        # Construct URL
        url = self.get_profiles.metadata['url']
        path_format_arguments = {
            'emsSystemId': self._serialize.url("ems_system_id", ems_system_id, 'int')
        }
        url = self._client.format_url(url, **path_format_arguments)

        # Construct parameters
        query_parameters = {}
        if group_id is not None:
            query_parameters['groupId'] = self._serialize.query("group_id", group_id, 'str')
        if search is not None:
            query_parameters['search'] = self._serialize.query("search", search, 'str')

        # Construct headers
        header_parameters = {}
        header_parameters['Accept'] = 'application/json'
        if custom_headers:
            header_parameters.update(custom_headers)

        # Construct and send request
        request = self._client.get(url, query_parameters, header_parameters)
        response = self._client.send(request, stream=False, **operation_config)

        if response.status_code not in [200, 401, 503]:
            raise HttpOperationError(self._deserialize, response)

        deserialized = None

        if response.status_code == 200:
            deserialized = self._deserialize('[AdiEmsWebApiV2DtoProfileProfile]', response)
        if response.status_code == 401:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)
        if response.status_code == 503:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)

        if raw:
            client_raw_response = ClientRawResponse(deserialized, response)
            return client_raw_response

        return deserialized
    get_profiles.metadata = {'url': '/v2/ems-systems/{emsSystemId}/profiles'}

    def get_profile_glossary(
            self, ems_system_id, profile_id, profile_version=None, format=None, custom_headers=None, raw=False, **operation_config):
        """Returns a "glossary" for a specific profile and version, which helps
        define the results that can be returned
        in a profile.

        <p>
        <strong>Please note:</strong> this API is prototypical in this release
        and its return values are subject
        to change in an upcoming release. In its current implementation, it is
        (1) including some unnecessary
        results and (2) not returning all available information.</p>
        <p>Use this API in conjunction with
        "ems-systems/{emsSystemId}/flights/{flightId}/profiles/{profileId}/query"
        API so you can interpret and
        better understand the results returned in the results.</p>.

        :param ems_system_id: The unique identifier of the system containing
         the EMS data.
        :type ems_system_id: int
        :param profile_id: The unique identifier of the profile whose glossary
         to return, e.g.
         "A7483C44-9DB9-4A44-9EB5-F67681EE52B0".
        :type profile_id: str
        :param profile_version: Integer version of the profile to return. If
         not specified the current version
         of the profile is used by default.
        :type profile_version: int
        :param format: The format of the returned glossary. Defaults to JSON.
         Possible values include: 'json', 'csv'
        :type format: str
        :param dict custom_headers: headers that will be added to the request
        :param bool raw: returns the direct response alongside the
         deserialized response
        :param operation_config: :ref:`Operation configuration
         overrides<msrest:optionsforoperations>`.
        :return: object or ClientRawResponse if raw=true
        :rtype: object or ~msrest.pipeline.ClientRawResponse
        :raises:
         :class:`HttpOperationError<msrest.exceptions.HttpOperationError>`
        """
        # Construct URL
        url = self.get_profile_glossary.metadata['url']
        path_format_arguments = {
            'emsSystemId': self._serialize.url("ems_system_id", ems_system_id, 'int'),
            'profileId': self._serialize.url("profile_id", profile_id, 'str')
        }
        url = self._client.format_url(url, **path_format_arguments)

        # Construct parameters
        query_parameters = {}
        if profile_version is not None:
            query_parameters['profileVersion'] = self._serialize.query("profile_version", profile_version, 'int')
        if format is not None:
            query_parameters['format'] = self._serialize.query("format", format, 'str')

        # Construct headers
        header_parameters = {}
        header_parameters['Accept'] = 'application/json'
        if custom_headers:
            header_parameters.update(custom_headers)

        # Construct and send request
        request = self._client.get(url, query_parameters, header_parameters)
        response = self._client.send(request, stream=False, **operation_config)

        if response.status_code not in [200, 401, 404, 503]:
            raise HttpOperationError(self._deserialize, response)

        deserialized = None

        if response.status_code == 200:
            deserialized = self._deserialize('AdiEmsWebApiV2DtoProfileProfileGlossary', response)
        if response.status_code == 401:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)
        if response.status_code == 404:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)
        if response.status_code == 503:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)

        if raw:
            client_raw_response = ClientRawResponse(deserialized, response)
            return client_raw_response

        return deserialized
    get_profile_glossary.metadata = {'url': '/v2/ems-systems/{emsSystemId}/profiles/{profileId}/glossary'}

    def get_profile_events(
            self, ems_system_id, profile_id, custom_headers=None, raw=False, **operation_config):
        """Returns the events for a specific profile.

        :param ems_system_id: The unique identifier of the system containing
         the EMS data.
        :type ems_system_id: int
        :param profile_id: The unique identifier of the profile whose events
         to return, e.g.
         "A7483C44-9DB9-4A44-9EB5-F67681EE52B0".
        :type profile_id: str
        :param dict custom_headers: headers that will be added to the request
        :param bool raw: returns the direct response alongside the
         deserialized response
        :param operation_config: :ref:`Operation configuration
         overrides<msrest:optionsforoperations>`.
        :return: object or ClientRawResponse if raw=true
        :rtype: object or ~msrest.pipeline.ClientRawResponse
        :raises:
         :class:`HttpOperationError<msrest.exceptions.HttpOperationError>`
        """
        # Construct URL
        url = self.get_profile_events.metadata['url']
        path_format_arguments = {
            'emsSystemId': self._serialize.url("ems_system_id", ems_system_id, 'int'),
            'profileId': self._serialize.url("profile_id", profile_id, 'str')
        }
        url = self._client.format_url(url, **path_format_arguments)

        # Construct parameters
        query_parameters = {}

        # Construct headers
        header_parameters = {}
        header_parameters['Accept'] = 'application/json'
        if custom_headers:
            header_parameters.update(custom_headers)

        # Construct and send request
        request = self._client.get(url, query_parameters, header_parameters)
        response = self._client.send(request, stream=False, **operation_config)

        if response.status_code not in [200, 401, 404, 503]:
            raise HttpOperationError(self._deserialize, response)

        deserialized = None

        if response.status_code == 200:
            deserialized = self._deserialize('[AdiEmsWebApiV2DtoProfileEvent]', response)
        if response.status_code == 401:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)
        if response.status_code == 404:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)
        if response.status_code == 503:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)

        if raw:
            client_raw_response = ClientRawResponse(deserialized, response)
            return client_raw_response

        return deserialized
    get_profile_events.metadata = {'url': '/v2/ems-systems/{emsSystemId}/profiles/{profileId}/events'}

    def get_event_parameter_set(
            self, ems_system_id, profile_id, event_id, custom_headers=None, raw=False, **operation_config):
        """Returns an event for a specific profile.

        :param ems_system_id: The unique identifier of the system containing
         the EMS data.
        :type ems_system_id: int
        :param profile_id: The unique identifier of the profile whose event
         parameter set is returned, e.g.
         "A7483C44-9DB9-4A44-9EB5-F67681EE52B0".
        :type profile_id: str
        :param event_id: The integer ID for the event.
        :type event_id: int
        :param dict custom_headers: headers that will be added to the request
        :param bool raw: returns the direct response alongside the
         deserialized response
        :param operation_config: :ref:`Operation configuration
         overrides<msrest:optionsforoperations>`.
        :return: object or ClientRawResponse if raw=true
        :rtype: object or ~msrest.pipeline.ClientRawResponse
        :raises:
         :class:`HttpOperationError<msrest.exceptions.HttpOperationError>`
        """
        # Construct URL
        url = self.get_event_parameter_set.metadata['url']
        path_format_arguments = {
            'emsSystemId': self._serialize.url("ems_system_id", ems_system_id, 'int'),
            'profileId': self._serialize.url("profile_id", profile_id, 'str'),
            'eventId': self._serialize.url("event_id", event_id, 'int')
        }
        url = self._client.format_url(url, **path_format_arguments)

        # Construct parameters
        query_parameters = {}

        # Construct headers
        header_parameters = {}
        header_parameters['Accept'] = 'application/json'
        if custom_headers:
            header_parameters.update(custom_headers)

        # Construct and send request
        request = self._client.get(url, query_parameters, header_parameters)
        response = self._client.send(request, stream=False, **operation_config)

        if response.status_code not in [200, 401, 404, 503]:
            raise HttpOperationError(self._deserialize, response)

        deserialized = None

        if response.status_code == 200:
            deserialized = self._deserialize('AdiEmsWebApiV2DtoProfileEvent', response)
        if response.status_code == 401:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)
        if response.status_code == 404:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)
        if response.status_code == 503:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)

        if raw:
            client_raw_response = ClientRawResponse(deserialized, response)
            return client_raw_response

        return deserialized
    get_event_parameter_set.metadata = {'url': '/v2/ems-systems/{emsSystemId}/profiles/{profileId}/events/{eventId}'}



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.pipeline import ClientRawResponse
from msrest.exceptions import HttpOperationError

from .. import models


class TableauOperations(object):
    """TableauOperations operations.

    :param client: Client for service requests.
    :param config: Configuration of service client.
    :param serializer: An object model serializer.
    :param deserializer: An object model deserializer.
    """

    models = models

    def __init__(self, client, config, serializer, deserializer):

        self._client = client
        self._serialize = serializer
        self._deserialize = deserializer

        self.config = config

    def get_trusted(
            self, site=None, custom_headers=None, raw=False, **operation_config):
        """Returns a Tableau "trusted" URL that consumers can use to gain access
        to Tableau content.

        <p>The returned "trusted" URL allows consumers connect to Tableau using
        the current user's security
        context. Once loaded in an iframe of a browser, Tableau sets a cookie
        to initiate the user's session.</p>.

        :param site: The name of the Tableau site for which to return a
         trusted URL. If not specified, the
         default site is used.
        :type site: str
        :param dict custom_headers: headers that will be added to the request
        :param bool raw: returns the direct response alongside the
         deserialized response
        :param operation_config: :ref:`Operation configuration
         overrides<msrest:optionsforoperations>`.
        :return: object or ClientRawResponse if raw=true
        :rtype: object or ~msrest.pipeline.ClientRawResponse
        :raises:
         :class:`HttpOperationError<msrest.exceptions.HttpOperationError>`
        """
        # Construct URL
        url = self.get_trusted.metadata['url']

        # Construct parameters
        query_parameters = {}
        if site is not None:
            query_parameters['site'] = self._serialize.query("site", site, 'str')

        # Construct headers
        header_parameters = {}
        header_parameters['Accept'] = 'application/json'
        if custom_headers:
            header_parameters.update(custom_headers)

        # Construct and send request
        request = self._client.get(url, query_parameters, header_parameters)
        response = self._client.send(request, stream=False, **operation_config)

        if response.status_code not in [200, 400, 401, 404, 500, 503]:
            raise HttpOperationError(self._deserialize, response)

        deserialized = None

        if response.status_code == 200:
            deserialized = self._deserialize('AdiEmsWebApiV2ModelTableauTrusted', response)
        if response.status_code == 400:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)
        if response.status_code == 401:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)
        if response.status_code == 404:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)
        if response.status_code == 500:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)
        if response.status_code == 503:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)

        if raw:
            client_raw_response = ClientRawResponse(deserialized, response)
            return client_raw_response

        return deserialized
    get_trusted.metadata = {'url': '/v2/tableau/trusted'}

    def get_tableau(
            self, site=None, custom_headers=None, raw=False, **operation_config):
        """Returns information about the configured EMS Online Tableau server.

        <p>The return is information about the Tableau server configured in EMS
        Online.</p>.

        :param site: The name of the Tableau site for which to return Tableau
         server information. If not specified, the default site is used.
        :type site: str
        :param dict custom_headers: headers that will be added to the request
        :param bool raw: returns the direct response alongside the
         deserialized response
        :param operation_config: :ref:`Operation configuration
         overrides<msrest:optionsforoperations>`.
        :return: object or ClientRawResponse if raw=true
        :rtype: object or ~msrest.pipeline.ClientRawResponse
        :raises:
         :class:`HttpOperationError<msrest.exceptions.HttpOperationError>`
        """
        # Construct URL
        url = self.get_tableau.metadata['url']

        # Construct parameters
        query_parameters = {}
        if site is not None:
            query_parameters['site'] = self._serialize.query("site", site, 'str')

        # Construct headers
        header_parameters = {}
        header_parameters['Accept'] = 'application/json'
        if custom_headers:
            header_parameters.update(custom_headers)

        # Construct and send request
        request = self._client.get(url, query_parameters, header_parameters)
        response = self._client.send(request, stream=False, **operation_config)

        if response.status_code not in [200, 400, 401, 404, 500, 503]:
            raise HttpOperationError(self._deserialize, response)

        deserialized = None

        if response.status_code == 200:
            deserialized = self._deserialize('AdiEmsWebApiV2ModelTableauTableauServer', response)
        if response.status_code == 400:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)
        if response.status_code == 401:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)
        if response.status_code == 404:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)
        if response.status_code == 500:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)
        if response.status_code == 503:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)

        if raw:
            client_raw_response = ClientRawResponse(deserialized, response)
            return client_raw_response

        return deserialized
    get_tableau.metadata = {'url': '/v2/tableau'}

    def get_sites(
            self, custom_headers=None, raw=False, **operation_config):
        """Returns the Tableau sites containing projects, workbooks and views the
        user can access.

        :param dict custom_headers: headers that will be added to the request
        :param bool raw: returns the direct response alongside the
         deserialized response
        :param operation_config: :ref:`Operation configuration
         overrides<msrest:optionsforoperations>`.
        :return: object or ClientRawResponse if raw=true
        :rtype: object or ~msrest.pipeline.ClientRawResponse
        :raises:
         :class:`HttpOperationError<msrest.exceptions.HttpOperationError>`
        """
        # Construct URL
        url = self.get_sites.metadata['url']

        # Construct parameters
        query_parameters = {}

        # Construct headers
        header_parameters = {}
        header_parameters['Accept'] = 'application/json'
        if custom_headers:
            header_parameters.update(custom_headers)

        # Construct and send request
        request = self._client.get(url, query_parameters, header_parameters)
        response = self._client.send(request, stream=False, **operation_config)

        if response.status_code not in [200, 401, 404, 500, 503]:
            raise HttpOperationError(self._deserialize, response)

        deserialized = None

        if response.status_code == 200:
            deserialized = self._deserialize('[AdiEmsWebSharedTableauRestSite]', response)
        if response.status_code == 401:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)
        if response.status_code == 404:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)
        if response.status_code == 500:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)
        if response.status_code == 503:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)

        if raw:
            client_raw_response = ClientRawResponse(deserialized, response)
            return client_raw_response

        return deserialized
    get_sites.metadata = {'url': '/v2/tableau/sites'}

    def get_site_projects(
            self, site_id, custom_headers=None, raw=False, **operation_config):
        """Returns the Tableau projects in the specified site, containing
        workbooks and views the user can access.

        :param site_id: The ID of the site containing the projects to return.
        :type site_id: str
        :param dict custom_headers: headers that will be added to the request
        :param bool raw: returns the direct response alongside the
         deserialized response
        :param operation_config: :ref:`Operation configuration
         overrides<msrest:optionsforoperations>`.
        :return: object or ClientRawResponse if raw=true
        :rtype: object or ~msrest.pipeline.ClientRawResponse
        :raises:
         :class:`HttpOperationError<msrest.exceptions.HttpOperationError>`
        """
        # Construct URL
        url = self.get_site_projects.metadata['url']
        path_format_arguments = {
            'siteId': self._serialize.url("site_id", site_id, 'str')
        }
        url = self._client.format_url(url, **path_format_arguments)

        # Construct parameters
        query_parameters = {}

        # Construct headers
        header_parameters = {}
        header_parameters['Accept'] = 'application/json'
        if custom_headers:
            header_parameters.update(custom_headers)

        # Construct and send request
        request = self._client.get(url, query_parameters, header_parameters)
        response = self._client.send(request, stream=False, **operation_config)

        if response.status_code not in [200, 401, 404, 500, 503]:
            raise HttpOperationError(self._deserialize, response)

        deserialized = None

        if response.status_code == 200:
            deserialized = self._deserialize('[AdiEmsWebSharedTableauRestProject]', response)
        if response.status_code == 401:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)
        if response.status_code == 404:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)
        if response.status_code == 500:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)
        if response.status_code == 503:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)

        if raw:
            client_raw_response = ClientRawResponse(deserialized, response)
            return client_raw_response

        return deserialized
    get_site_projects.metadata = {'url': '/v2/tableau/sites/{siteId}/projects'}

    def get_site_workbooks(
            self, site_id, custom_headers=None, raw=False, **operation_config):
        """Returns the Tableau workbooks in the specified site, containing views
        the user can access.

        :param site_id: The ID of the site containing the workbooks to return.
        :type site_id: str
        :param dict custom_headers: headers that will be added to the request
        :param bool raw: returns the direct response alongside the
         deserialized response
        :param operation_config: :ref:`Operation configuration
         overrides<msrest:optionsforoperations>`.
        :return: object or ClientRawResponse if raw=true
        :rtype: object or ~msrest.pipeline.ClientRawResponse
        :raises:
         :class:`HttpOperationError<msrest.exceptions.HttpOperationError>`
        """
        # Construct URL
        url = self.get_site_workbooks.metadata['url']
        path_format_arguments = {
            'siteId': self._serialize.url("site_id", site_id, 'str')
        }
        url = self._client.format_url(url, **path_format_arguments)

        # Construct parameters
        query_parameters = {}

        # Construct headers
        header_parameters = {}
        header_parameters['Accept'] = 'application/json'
        if custom_headers:
            header_parameters.update(custom_headers)

        # Construct and send request
        request = self._client.get(url, query_parameters, header_parameters)
        response = self._client.send(request, stream=False, **operation_config)

        if response.status_code not in [200, 401, 404, 500, 503]:
            raise HttpOperationError(self._deserialize, response)

        deserialized = None

        if response.status_code == 200:
            deserialized = self._deserialize('[AdiEmsWebSharedTableauRestWorkbook]', response)
        if response.status_code == 401:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)
        if response.status_code == 404:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)
        if response.status_code == 500:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)
        if response.status_code == 503:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)

        if raw:
            client_raw_response = ClientRawResponse(deserialized, response)
            return client_raw_response

        return deserialized
    get_site_workbooks.metadata = {'url': '/v2/tableau/sites/{siteId}/workbooks'}

    def get_site_workbook_views(
            self, site_id, workbook_id, custom_headers=None, raw=False, **operation_config):
        """Returns the Tableau views in the specified site and workbook,
        containing content the user can visualize.

        :param site_id: The ID of the site containing the view.
        :type site_id: str
        :param workbook_id: The ID of the workbook containing the view.
        :type workbook_id: str
        :param dict custom_headers: headers that will be added to the request
        :param bool raw: returns the direct response alongside the
         deserialized response
        :param operation_config: :ref:`Operation configuration
         overrides<msrest:optionsforoperations>`.
        :return: object or ClientRawResponse if raw=true
        :rtype: object or ~msrest.pipeline.ClientRawResponse
        :raises:
         :class:`HttpOperationError<msrest.exceptions.HttpOperationError>`
        """
        # Construct URL
        url = self.get_site_workbook_views.metadata['url']
        path_format_arguments = {
            'siteId': self._serialize.url("site_id", site_id, 'str'),
            'workbookId': self._serialize.url("workbook_id", workbook_id, 'str')
        }
        url = self._client.format_url(url, **path_format_arguments)

        # Construct parameters
        query_parameters = {}

        # Construct headers
        header_parameters = {}
        header_parameters['Accept'] = 'application/json'
        if custom_headers:
            header_parameters.update(custom_headers)

        # Construct and send request
        request = self._client.get(url, query_parameters, header_parameters)
        response = self._client.send(request, stream=False, **operation_config)

        if response.status_code not in [200, 401, 404, 500, 503]:
            raise HttpOperationError(self._deserialize, response)

        deserialized = None

        if response.status_code == 200:
            deserialized = self._deserialize('[AdiEmsWebSharedTableauRestView]', response)
        if response.status_code == 401:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)
        if response.status_code == 404:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)
        if response.status_code == 500:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)
        if response.status_code == 503:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)

        if raw:
            client_raw_response = ClientRawResponse(deserialized, response)
            return client_raw_response

        return deserialized
    get_site_workbook_views.metadata = {'url': '/v2/tableau/sites/{siteId}/workbooks/{workbookId}/views'}



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AdiEmsWebApiV2DtoProfileProfileResultComment(Model):
    """Encapsulates information about a comment.

    All required parameters must be populated in order to send to Azure.

    :param user: Required. The user associated with the comment
    :type user: str
    :param date_property: Required. The date and time the comment was added
     (UTC)
    :type date_property: datetime
    :param comment: Required. The text of the comment
    :type comment: str
    """

    _validation = {
        'user': {'required': True},
        'date_property': {'required': True},
        'comment': {'required': True},
    }

    _attribute_map = {
        'user': {'key': 'user', 'type': 'str'},
        'date_property': {'key': 'date', 'type': 'iso-8601'},
        'comment': {'key': 'comment', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(AdiEmsWebApiV2DtoProfileProfileResultComment, self).__init__(**kwargs)
        self.user = kwargs.get('user', None)
        self.date_property = kwargs.get('date_property', None)
        self.comment = kwargs.get('comment', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AdiEmsWebApiV2DtoTrajectoryConfiguration(Model):
    """Encapsulates a data point defining the userOptions config for a Google
    Earth export.

    :param trajectory_id: A unique identifier for this type of KML trajectory.
     Typically this just the name of the file sans extension.
    :type trajectory_id: str
    :param description: A description of what kind of trajectory this KML type
     generates.
    :type description: str
    """

    _attribute_map = {
        'trajectory_id': {'key': 'trajectoryId', 'type': 'str'},
        'description': {'key': 'description', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(AdiEmsWebApiV2DtoTrajectoryConfiguration, self).__init__(**kwargs)
        self.trajectory_id = kwargs.get('trajectory_id', None)
        self.description = kwargs.get('description', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AdiEmsWebApiV2DtoWeatherMetarMetarQuery(Model):
    """Defines the options that can be used to query for METAR reports.

    :param airport_id: Optional airport ID for an airport returned by the
     Assets APIs. If set then ICAO code should not be set
    :type airport_id: int
    :param airport_icao: Optional airport ICAO code. If set then airportId
     should not be set
    :type airport_icao: str
    :param observation_range_from: Optional date range from filter. If set all
     METARs issued after this value will be returned
    :type observation_range_from: datetime
    :param observation_range_to: Optional date range to filter. If set all
     METARs issued before this value will be returned
    :type observation_range_to: datetime
    :param visibility_minimum: Optional value indicating the minimum observed
     visibility in miles
    :type visibility_minimum: float
    :param visibility_maximum: Optional value indicating the maximum observed
     visibility in miles
    :type visibility_maximum: float
    :param ceiling_minimum: Optional value indicating the minimum observed
     ceiling in feet
    :type ceiling_minimum: float
    :param ceiling_maximum: Optional value indicating the maximum observed
     ceiling in feet
    :type ceiling_maximum: float
    :param max_results: The maximum number of results to return. If set to 0
     all results will be returned. This defaults to 200
    :type max_results: int
    """

    _attribute_map = {
        'airport_id': {'key': 'airportId', 'type': 'int'},
        'airport_icao': {'key': 'airportIcao', 'type': 'str'},
        'observation_range_from': {'key': 'observationRangeFrom', 'type': 'iso-8601'},
        'observation_range_to': {'key': 'observationRangeTo', 'type': 'iso-8601'},
        'visibility_minimum': {'key': 'visibilityMinimum', 'type': 'float'},
        'visibility_maximum': {'key': 'visibilityMaximum', 'type': 'float'},
        'ceiling_minimum': {'key': 'ceilingMinimum', 'type': 'float'},
        'ceiling_maximum': {'key': 'ceilingMaximum', 'type': 'float'},
        'max_results': {'key': 'maxResults', 'type': 'int'},
    }

    def __init__(self, *, airport_id: int=None, airport_icao: str=None, observation_range_from=None, observation_range_to=None, visibility_minimum: float=None, visibility_maximum: float=None, ceiling_minimum: float=None, ceiling_maximum: float=None, max_results: int=None, **kwargs) -> None:
        super(AdiEmsWebApiV2DtoWeatherMetarMetarQuery, self).__init__(**kwargs)
        self.airport_id = airport_id
        self.airport_icao = airport_icao
        self.observation_range_from = observation_range_from
        self.observation_range_to = observation_range_to
        self.visibility_minimum = visibility_minimum
        self.visibility_maximum = visibility_maximum
        self.ceiling_minimum = ceiling_minimum
        self.ceiling_maximum = ceiling_maximum
        self.max_results = max_results



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AdiEmsWebApiV2DtoProfileProfileResults(Model):
    """Encapsulates all the profile results for a flight.

    All required parameters must be populated in order to send to Azure.

    :param profile_version: Required. The integer version of the profile that
     was processed to generate the results,
     corresponding to an index in the array of version history entries for the
     profile
    :type profile_version: int
    :param parameter_filtering: Required. Indicates whether automatic
     parameter filtering was enabled when the profile was processed
    :type parameter_filtering: bool
    :param measurements: Required. The top-level, non-event-based, measurement
     results
    :type measurements:
     list[~emsapi.models.AdiEmsWebApiV2DtoProfileProfileResultValue]
    :param timepoints: Required. The top-level, non-event-based, timepoint
     results
    :type timepoints:
     list[~emsapi.models.AdiEmsWebApiV2DtoProfileProfileResultValue]
    :param events: Required. The event results detected in the flight
    :type events:
     list[~emsapi.models.AdiEmsWebApiV2DtoProfileProfileResultsEventRecord]
    """

    _validation = {
        'profile_version': {'required': True},
        'parameter_filtering': {'required': True},
        'measurements': {'required': True},
        'timepoints': {'required': True},
        'events': {'required': True},
    }

    _attribute_map = {
        'profile_version': {'key': 'profileVersion', 'type': 'int'},
        'parameter_filtering': {'key': 'parameterFiltering', 'type': 'bool'},
        'measurements': {'key': 'measurements', 'type': '[AdiEmsWebApiV2DtoProfileProfileResultValue]'},
        'timepoints': {'key': 'timepoints', 'type': '[AdiEmsWebApiV2DtoProfileProfileResultValue]'},
        'events': {'key': 'events', 'type': '[AdiEmsWebApiV2DtoProfileProfileResultsEventRecord]'},
    }

    def __init__(self, *, profile_version: int, parameter_filtering: bool, measurements, timepoints, events, **kwargs) -> None:
        super(AdiEmsWebApiV2DtoProfileProfileResults, self).__init__(**kwargs)
        self.profile_version = profile_version
        self.parameter_filtering = parameter_filtering
        self.measurements = measurements
        self.timepoints = timepoints
        self.events = events



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AdiEmsWebApiV2DtoWeatherCloudCondition(Model):
    """Describes the condition of clouds in the sky.

    :param cloud_base: Specifies the height of the base of a visual portion of
     a cloud. Uses "Infinity" to designate there is no
     limit
    :type cloud_base: float
    :param cloud_type: Describes the types of clouds appearing in the sky.
     Possible values include: 'none', 'cumulonimbus', 'toweringCumulis',
     'cumulusMediocris'
    :type cloud_type: str or ~emsapi.models.enum
    :param cloud_coverage: Describes the type of cloud cover appearing in the
     sky. Possible values include: 'none', 'few', 'scattered', 'broken',
     'overcast', 'verticalVisibility', 'clear'
    :type cloud_coverage: str or ~emsapi.models.enum
    """

    _attribute_map = {
        'cloud_base': {'key': 'cloudBase', 'type': 'float'},
        'cloud_type': {'key': 'cloudType', 'type': 'str'},
        'cloud_coverage': {'key': 'cloudCoverage', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(AdiEmsWebApiV2DtoWeatherCloudCondition, self).__init__(**kwargs)
        self.cloud_base = kwargs.get('cloud_base', None)
        self.cloud_type = kwargs.get('cloud_type', None)
        self.cloud_coverage = kwargs.get('cloud_coverage', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AdiEmsWebApiV2ModelAnalyticQuery(Model):
    """Represents the options used to make up an analytic query.

    All required parameters must be populated in order to send to Azure.

    :param select: Required. An array specifying the analytics to select and
     return in query results. Use null or an empty array to
     return only offset values
    :type select:
     list[~emsapi.models.AdiEmsWebApiV2ModelAnalyticAnalyticSelect]
    :param start: The optional start offset in the data, in seconds from the
     start of the data. If not specified, the
     beginning of the available data is used
    :type start: float
    :param end: The optional end offset in the data, in seconds from the start
     of the data. If not specified, the
     end of the available data is used
    :type end: float
    :param offsets: The optional set of offsets to return in query results.
     Use as an alternative to specifying a range of
     values using start and end
    :type offsets: list[float]
    :param size: The optional limit that specifies the total number of offsets
     and values to return in query results
    :type size: int
    :param unsampled_data_mode: This determines how to treat data values for
     offsets that are not sampled. If left unset this defaults to 'leaveBlank'.
     This only applies when performing queries using "offsetType". Possible
     values include: 'leaveBlank', 'uniquePreviousSample', 'stairStep',
     'linearInterpolation', 'parameterDefault', 'previousSample'
    :type unsampled_data_mode: str or ~emsapi.models.enum
    :param unsampled_value: This optional parameter replaces any unsampled
     (blank) values with a constant value. This defaults to a null value.
     This only applies when performing queries using "offsetType"
    :type unsampled_value: str
    :param does_not_exist_value: This optional parameter replaces any values
     that come back as DNE (does not exist) with a constant value. This
     defaults to "DNE".
     This only applies when performing queries using "offsetType"
    :type does_not_exist_value: str
    :param offset_type: This defines the way in which the offsets are
     determined. This is required if Offsets or Size has not been set
    :type offset_type: ~emsapi.models.AdiEmsWebApiV2ModelAnalyticOffsetType
    :param discretes_as_strings: This optional parameter, when set to true,
     displays discrete values as their respective string values. This defaults
     to true.
     This only applies when performing queries using "offsetType"
    :type discretes_as_strings: bool
    """

    _validation = {
        'select': {'required': True},
    }

    _attribute_map = {
        'select': {'key': 'select', 'type': '[AdiEmsWebApiV2ModelAnalyticAnalyticSelect]'},
        'start': {'key': 'start', 'type': 'float'},
        'end': {'key': 'end', 'type': 'float'},
        'offsets': {'key': 'offsets', 'type': '[float]'},
        'size': {'key': 'size', 'type': 'int'},
        'unsampled_data_mode': {'key': 'unsampledDataMode', 'type': 'str'},
        'unsampled_value': {'key': 'unsampledValue', 'type': 'str'},
        'does_not_exist_value': {'key': 'doesNotExistValue', 'type': 'str'},
        'offset_type': {'key': 'offsetType', 'type': 'AdiEmsWebApiV2ModelAnalyticOffsetType'},
        'discretes_as_strings': {'key': 'discretesAsStrings', 'type': 'bool'},
    }

    def __init__(self, **kwargs):
        super(AdiEmsWebApiV2ModelAnalyticQuery, self).__init__(**kwargs)
        self.select = kwargs.get('select', None)
        self.start = kwargs.get('start', None)
        self.end = kwargs.get('end', None)
        self.offsets = kwargs.get('offsets', None)
        self.size = kwargs.get('size', None)
        self.unsampled_data_mode = kwargs.get('unsampled_data_mode', None)
        self.unsampled_value = kwargs.get('unsampled_value', None)
        self.does_not_exist_value = kwargs.get('does_not_exist_value', None)
        self.offset_type = kwargs.get('offset_type', None)
        self.discretes_as_strings = kwargs.get('discretes_as_strings', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AdiEmsWebApiCoreDtoDataRange(Model):
    """AdiEmsWebApiCoreDtoDataRange.

    :param min:
    :type min: float
    :param max:
    :type max: float
    """

    _attribute_map = {
        'min': {'key': 'min', 'type': 'float'},
        'max': {'key': 'max', 'type': 'float'},
    }

    def __init__(self, *, min: float=None, max: float=None, **kwargs) -> None:
        super(AdiEmsWebApiCoreDtoDataRange, self).__init__(**kwargs)
        self.min = min
        self.max = max



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AdiEmsWebApiV2DtoWeatherTafTafParseOptions(Model):
    """Specifies options to use when calling the TAF parse API.

    All required parameters must be populated in order to send to Azure.

    :param taf: Required. The raw TAF string to parse
    :type taf: str
    :param issue_date: Required. Date information (in ISO 8601 format) the TAF
     was issued, since the TAF format doesn't include this
     information
    :type issue_date: datetime
    """

    _validation = {
        'taf': {'required': True},
        'issue_date': {'required': True},
    }

    _attribute_map = {
        'taf': {'key': 'taf', 'type': 'str'},
        'issue_date': {'key': 'issueDate', 'type': 'iso-8601'},
    }

    def __init__(self, *, taf: str, issue_date, **kwargs) -> None:
        super(AdiEmsWebApiV2DtoWeatherTafTafParseOptions, self).__init__(**kwargs)
        self.taf = taf
        self.issue_date = issue_date



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AdiEmsWebApiV2DtoSchemaQuery(Model):
    """Represents the options used to make up a data source query.

    All required parameters must be populated in order to send to Azure.

    :param select: Required. An array specifying the fields to select and
     return as columns in the query results
    :type select: list[~emsapi.models.AdiEmsWebApiV2DtoSchemaSelectColumn]
    :param group_by: An array specifying the fields by which to group
     aggregate operations. If not specified, no grouping
     is performed
    :type group_by: list[~emsapi.models.AdiEmsWebApiV2DtoSchemaGroupByColumn]
    :param order_by: An array specifying the selected columns by which to
     order result rows. Results are always ordered by the
     results value, not by the display formatted value (configured to be
     returned by the format property). If
     not specified, results are returned in default database ordering
    :type order_by: list[~emsapi.models.AdiEmsWebApiV2DtoSchemaOrderByColumn]
    :param filter: A filter used to narrow the query results
    :type filter: ~emsapi.models.AdiEmsWebApiV2DtoSchemaFilter
    :param format: Value formatting that should be performed on results values
     before returning. If not specified, no results
     formatting is performed. This can be overridden by specifying a value for
     the Format property of a SelectColumn. Possible values include: 'none',
     'display'
    :type format: str or ~emsapi.models.enum
    :param distinct: Whether to remove duplicate rows from query results
     <b>before formatting</b> the results. Using a format
     value other than 'none' can reduce results precision, leading to cases
     where two distinct rows appear
     equivalent after formatting is applied. Defaults to false if not specified
    :type distinct: bool
    :param top: Identifies a subset of rows to return.
     The subset is formed by selecting only the first N rows of the set, where
     N is a positive integer provided
     as the value of this property. If not specified, all rows are returned
    :type top: int
    """

    _validation = {
        'select': {'required': True},
    }

    _attribute_map = {
        'select': {'key': 'select', 'type': '[AdiEmsWebApiV2DtoSchemaSelectColumn]'},
        'group_by': {'key': 'groupBy', 'type': '[AdiEmsWebApiV2DtoSchemaGroupByColumn]'},
        'order_by': {'key': 'orderBy', 'type': '[AdiEmsWebApiV2DtoSchemaOrderByColumn]'},
        'filter': {'key': 'filter', 'type': 'AdiEmsWebApiV2DtoSchemaFilter'},
        'format': {'key': 'format', 'type': 'str'},
        'distinct': {'key': 'distinct', 'type': 'bool'},
        'top': {'key': 'top', 'type': 'int'},
    }

    def __init__(self, **kwargs):
        super(AdiEmsWebApiV2DtoSchemaQuery, self).__init__(**kwargs)
        self.select = kwargs.get('select', None)
        self.group_by = kwargs.get('group_by', None)
        self.order_by = kwargs.get('order_by', None)
        self.filter = kwargs.get('filter', None)
        self.format = kwargs.get('format', None)
        self.distinct = kwargs.get('distinct', None)
        self.top = kwargs.get('top', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AdiEmsWebApiV2DtoUploadUploadRequest(Model):
    """Encapsulates information that will be returned when beginning a new data
    ingestion transfer.

    :param name: The name of the transfer; this is not necessarily unique, and
     is just what the user passed
     when they initiated the transfer.
    :type name: str
    :param type: The type of the upload; this is the handler that we will use
     to process the uploaded data.
     The format of the data will be determined by what this upload type is.
     Possible values include: 'emsCollectionZipped', 'testTransfer',
     'emsCollectionRaw'
    :type type: str or ~emsapi.models.enum
    :param password: The password the data is encrypted with, if any. This
     point of the encryption possibility
     is that this may be part of a store-and-forward system that stores the
     data encrypted locally.
     (Thus passing it here along with the data is not particularly a security
     issue, but rather
     a way to avoid having to decrypt it as it transfers.)
     Note: This is not currently supported with any of the UploadTypes but may
     be in the future.
    :type password: str
    :param total_size: The total size of the data to be transferred. This may
     be absent in the case where the upload
     is being streamed and the total size is unknown. If provided this allows
     you to skip making a
     Finish call to the API to explicitly finish the transfer. Instead a Finish
     will be inferred
     when sufficient bytes have been sent.
    :type total_size: long
    :param metadata: Arbitrary metadata attached to the transfer record. This
     may be used by post-processing later
     or for other uses. If this is one of the EMS Collection UploadTypes then
     this information will
     be added to the generated ident.xml.
    :type metadata: dict[str, str]
    """

    _attribute_map = {
        'name': {'key': 'name', 'type': 'str'},
        'type': {'key': 'type', 'type': 'str'},
        'password': {'key': 'password', 'type': 'str'},
        'total_size': {'key': 'totalSize', 'type': 'long'},
        'metadata': {'key': 'metadata', 'type': '{str}'},
    }

    def __init__(self, **kwargs):
        super(AdiEmsWebApiV2DtoUploadUploadRequest, self).__init__(**kwargs)
        self.name = kwargs.get('name', None)
        self.type = kwargs.get('type', None)
        self.password = kwargs.get('password', None)
        self.total_size = kwargs.get('total_size', None)
        self.metadata = kwargs.get('metadata', None)
